<?php
/**
 * Adds help tours and help content.
 */
class HelpToursAndContent extends Migration
{
    function description()
    {
        return 'Adds help tours and help content.';
    }

    function up()
    {
        $this->addHelpTours();
        $this->addHelpContent();
        $this->addHelpContentEN();

        // set version in config
        $version = '3.1';
        // see migrate_help_content.php
        if (!Config::get()->getValue('HELP_CONTENT_CURRENT_VERSION')) {
            Config::get()->create('HELP_CONTENT_CURRENT_VERSION', [
                'value' => $version,
                'is_default' => 0,
                'type' => 'string',
                'range' => 'global',
                'section' => 'global',
                'description' => 'Aktuelle Version der Helpbar-Einträge in Stud.IP'
                ]);
        } else {
            Config::get()->store('HELP_CONTENT_CURRENT_VERSION', $version);
        }
    }

    function down()
    {
        DBManager::get()->exec("TRUNCATE TABLE `help_content`");
        DBManager::get()->exec("TRUNCATE TABLE `help_tours`");
        DBManager::get()->exec("TRUNCATE TABLE `help_tour_settings`");
        DBManager::get()->exec("TRUNCATE TABLE `help_tour_steps`");
    }

    function addHelpTours() {
        // add tour data
        $query = "INSERT IGNORE INTO `help_tours` (`tour_id`, `name`, `description`, `type`, `roles`, `version`, `language`, `studip_version`, `installation_id`, `mkdate`) VALUES
('96ea422f286fb5bbf9e41beadb484a9a', 'Profilseite', 'In dieser Tour werden die Grundfunktionen und Bereiche der Profilseite vorgestellt.', 'tour', 'autor,dozent,root', 1, 'de', '3.1', '', 1406722657),
('25e7421f286fc5bdf9e41beadb484ffa', 'Eigenes Bild hochladen', 'In der Tour wird erklärt, wie Nutzende ein eigenes Profilbild hochladen können.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1406722657),
('3629493a16bf2680de64361f07cab096', 'Blubber', 'In der Tour wird die Nutzung von Blubber erklärt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1406709759),
('21f487fa74e3bfc7789886f40fe4131a', 'Forum nutzen', 'Die Inhalte dieser Tour stammen aus der alten Tour des Forums (Sidebar > Aktionen > Tour starten).', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405415746),
('44f859c50648d3410c39207048ddd833', 'Forum verwalten', 'Die Inhalte dieser Tour stammen aus der alten Tour des Forums (Sidebar > Aktionen > Tour starten).', 'tour', 'tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405417901),
('3a717a468afb0822cb1455e0ae6b6fce', 'Blubber', 'In der Tour wird die Nutzung von Blubber erklärt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1406709041),
('ef5092ba722c81c37a5a6bd703890bd9', 'Blubber', 'In der Tour wird die Nutzung von Blubber erklärt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405507317),
('6849293baa05be5bef8ff438dc7c438b', 'Suche', 'In dieser Feature-Tour werden die wichtigsten Funktionen der Suche vorgestellt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405519609),
('b74f8459dce2437463096d56db7c73b9', 'Meine Veranstaltungen (Studierende)', 'In dieser Tour werden die wichtigsten Funktionen der Seite \"Meine Veranstaltungen\" vorgestellt.', 'tour', 'autor,admin,root', 1, 'de', '3.1', '', 1405521073),
('154e711257d4d32d865fb8f5fb70ad72', 'Meine Dateien', 'In dieser Tour wird der persönliche Dateibereich vorgestellt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405592618),
('19ac063e8319310d059d28379139b1cf', 'Studiengruppe anlegen', 'In dieser Tour wird das Anlegen von Studiengruppen erklärt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405684299),
('edfcf78c614869724f93488c4ed09582', 'Teilnehmerverwaltung', 'In dieser Tour werden die Verwaltungsoptionen der Teilnehmerverwaltung erklärt.', 'tour', 'tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405688156),
('977f41c5c5239c4e86f04c3df27fae38', 'Was ist neu in Stud.IP 3.1?', 'In dieser Tour werden die Neuerungen in Stud.IP 3.1 überblicksartig vorgestellt.', 'tour', 'autor,tutor,dozent,admin', 1, 'de', '3.1', '', 1405932260),
('49604a77654617a745e29ad6b253e491', 'Gestaltung der Startseite', 'In dieser Tour werden die Funktionen und Gestaltungsmöglichkeiten der Startseite vorgestellt.', 'tour', 'autor,tutor,dozent,admin,root', 1, 'de', '3.1', '', 1405934780),
('7cccbe3b22dfa745c17cb776fb04537c', 'Meine Veranstaltungen (Lehrende)', 'In dieser Tour werden die wichtigsten Funktionen der Seite \"Meine Veranstaltungen\" vorgestellt.', 'tour', 'tutor,dozent,admin,root', 1, 'de', '3.1', '', 1406125685);
";
        DBManager::get()->exec($query);

        // add steps
        $query = "INSERT IGNORE INTO `help_tour_steps` (`tour_id`, `step`, `title`, `tip`, `orientation`, `interactive`, `css_selector`, `route`, `author_id`, `mkdate`) VALUES
('96ea422f286fb5bbf9e41beadb484a9a', 3, 'Stud.IP-Score', 'Der Stud.IP-Score wächst mit den Aktivitäten in Stud.IP und repräsentiert so die Erfahrung mit Stud.IP.', 'BL', 0, '#layout_content TABLE:eq(0) TBODY:eq(0) TR:eq(0) TD:eq(0) A:eq(0)', 'dispatch.php/profile', '', 1406722657),
('96ea422f286fb5bbf9e41beadb484a9a', 5, 'Neue Ankündigung', 'Klicken Sie auf das Plus-Zeichen, wenn Sie eine Ankündigung erstellen möchten.', 'BR', 0, '.contentbox:eq(0) header img:eq(1)', 'dispatch.php/profile', '', 1406722657),
('96ea422f286fb5bbf9e41beadb484a9a', 1, 'Profil-Tour', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen des \"Profils\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'T', 0, '', 'dispatch.php/profile', '', 1406722657),
('96ea422f286fb5bbf9e41beadb484a9a', 6, 'Persönliche Daten', 'Das Bild sowie weitere persönliche Angaben können über diese Seiten geändert werden.', 'BL', 0, '#tabs li:eq(2)', 'dispatch.php/profile', '', 1406722657),
('96ea422f286fb5bbf9e41beadb484a9a', 2, 'Persönliches Bild', 'Wenn ein Bild hochgeladen wurde, wird es hier angezeigt. Dieses kann jederzeit geändert werden.', 'RT', 0, '.avatar-normal', 'dispatch.php/profile', '', 1406722657),
('25e7421f286fc5bdf9e41beadb484ffa', 1, 'Profil', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen des \"Profils\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'B', 0, '', 'dispatch.php/profile', '', 1406722657),
('25e7421f286fc5bdf9e41beadb484ffa', 2, 'Bild hochladen', 'Auf dieser Seite lässt sich ein Profilbild hochladen.', 'BL', 0, '#nav_profile_avatar A SPAN', 'dispatch.php/settings/avatar', '', 1406722657),
('25e7421f286fc5bdf9e41beadb484ffa', 3, 'Bild auswählen', 'Dafür kann eine beliebige Bilddatei hochgeladen werden.', 'L', 0, 'input[name=imgfile]', 'dispatch.php/settings/avatar', '', 1406722657),
('96ea422f286fb5bbf9e41beadb484a9a', 4, 'Ankündigungen', 'Sie können auf dieser Seite persönliche Ankündigungen veröffentlichen.', 'B', 0, '#layout_content SECTION HEADER H1 :eq(0)', 'dispatch.php/profile', '', 1406722657),
('3629493a16bf2680de64361f07cab096', 3, 'Text gestalten', 'Der Text kann formatiert und mit Smileys versehen werden.\r\nEs können die üblichen Formatierungen verwendet werden, wie z. B. **fett** oder %%kursiv%%.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/forum', '', 1405508371),
('6849293baa05be5bef8ff438dc7c438b', 4, 'Navigation', 'Falls nur in einem bestimmten Bereich (wie z.B. Lehre) gesucht werden soll, kann dieser hier ausgewählt werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(0)', 'dispatch.php/search/courses', '', 1406121826),
('3a717a468afb0822cb1455e0ae6b6fce', 3, 'Text gestalten', 'Der Text kann formatiert und mit Smileys versehen werden.\r\nEs können die üblichen Formatierungen verwendet werden, wie z. B. **fett** oder %%kursiv%%.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/profile', '', 1405508371),
('3629493a16bf2680de64361f07cab096', 9, 'Beitrag verlinken', 'Wird der Mauszeiger auf dem ersten Diskussionsbeitrag positioniert, erscheint links neben dem Datum ein Link-Icon. Wenn dieses mit der rechten Maustaste angeklickt wird, kann der Link auf diesen Beitrag kopiert werden, um ihn an anderer Stelle einfügen zu können.', 'BR', 0, 'DIV DIV A.permalink', 'plugins.php/blubber/streams/forum', '', 1405508281),
('3629493a16bf2680de64361f07cab096', 8, 'Beitrag ändern', 'Wird der Mauszeiger auf einem beliebigen Beitrag positioniert, erscheint dessen Datum. Bei eigenen Beiträgen erscheint außerdem rechts neben dem Datum ein Icon, mit dem der Beitrag nachträglich geändert werden kann.', 'BR', 0, 'DIV DIV A SPAN.time', 'plugins.php/blubber/streams/forum', '', 1405507901),
('21f487fa74e3bfc7789886f40fe4131a', 1, 'Forum', 'Diese Tour gibt einen Überblick über die Elemente und Interaktionsmöglichkeiten des Forums.\r\n\r\nUm zum nächsten Schritt zu gelangen, klicken Sie bitte rechts unten auf \"Weiter\".', 'BL', 0, '', 'plugins.php/coreforum', '', 1405415772),
('21f487fa74e3bfc7789886f40fe4131a', 2, 'Sie befinden sich hier:...', 'An dieser Stelle wird angezeigt, welcher Bereich des Forums gerade betrachtet wird.', 'BL', 0, 'DIV#tutorBreadcrumb', 'plugins.php/coreforum', '', 1405415875),
('44f859c50648d3410c39207048ddd833', 1, 'Forum verwalten', 'Sie haben die Möglichkeit sich eine Tour zur Verwaltung des Forums anzuschauen.\r\n\r\nUm die Tour zu beginnen, klicken Sie bitte unten rechts auf \"Weiter\".', 'TL', 0, '', 'plugins.php/coreforum', '', 1405418008),
('21f487fa74e3bfc7789886f40fe4131a', 3, 'Kategorie', 'Das Forum ist unterteilt in Kategorien, Themen und Beiträge. Eine Kategorie fasst Forumsbereiche in größere Sinneinheiten zusammen.', 'BL', 0, '#layout_content #forum #sortable_areas TABLE CAPTION .category_name :eq(0)', 'plugins.php/coreforum', '', 1405416611),
('21f487fa74e3bfc7789886f40fe4131a', 4, 'Bereich', 'Das ist ein Bereich innerhalb einer Kategorie. Bereiche beinhalten die Diskussionstränge. Bereiche können mit per drag & drop in ihrer Reihenfolge verschoben werden.', 'BL', 0, '#layout_content #forum TABLE THEAD TR TH :eq(0)', 'plugins.php/coreforum', '', 1405416664),
('21f487fa74e3bfc7789886f40fe4131a', 5, 'Info-Icon', 'Dieses Icon färbt sich rot, sobald es etwas neues in diesem Bereich gibt.', 'B', 0, 'IMG#tutorNotificationIcon', 'plugins.php/coreforum', '', 1405416705),
('21f487fa74e3bfc7789886f40fe4131a', 7, 'Forum abonnieren', 'Das gesamte Forum, oder einzelne Themen können abonniert werden. Dann wird bei jedem neuen Beitrag in diesem Forum eine Benachrichtigung angezeigt und eine Nachricht versendet.', 'B', 0, '#layout-sidebar SECTION DIV DIV UL LI A :eq(5)', 'plugins.php/coreforum', '', 1405416795),
('21f487fa74e3bfc7789886f40fe4131a', 6, 'Suchen', 'Hier können sämtliche Inhalte dieses Forums durchsucht werden.\r\nUnterstützt werden auch Mehrwortsuchen. Außerdem kann die Suche auf eine beliebige Kombination aus Titel, Inhalt und Autor eingeschränkt werden.', 'BL', 0, '#layout-sidebar SECTION #tutorSearchInfobox DIV #tutorSearchInfobox UL LI INPUT :eq(1)', 'plugins.php/coreforum', '', 1405417134),
('44f859c50648d3410c39207048ddd833', 2, 'Kategorie bearbeiten', 'Mit diesen Icons kann der Name der Kategorie geändert oder aber die gesamte Kategorie gelöscht werden. Die Bereiche werden in diesem Fall in die Kategorie \"Allgemein\" verschoben und bleiben somit erhalten.\r\n\r\nDie Kategorie \"Allgemein\" kann nicht gelöscht werden und ist daher in jedem Forum enthalten.', 'BR', 0, '#forum #sortable_areas TABLE CAPTION #tutorCategoryIcons', 'plugins.php/coreforum', '', 1405424216),
('44f859c50648d3410c39207048ddd833', 3, 'Bereich bearbeiten', 'Wird der Mauszeiger auf einem Bereich positioniert, erscheinen Aktions-Icons.\r\nMit diesen Icons kann der Name und die Beschreibung eines Bereiches geändert oder auch der gesamte Bereich gelöscht werden.\r\nDas Löschen eines Bereichs, führt dazu, dass alle enthaltenen Themen gelöscht werden.', 'B', 0, 'IMG.edit-area', 'plugins.php/coreforum', '', 1405424346),
('44f859c50648d3410c39207048ddd833', 4, 'Bereiche sortieren', 'Mit dieser schraffierten Fläche können Bereiche an einer beliebigen Stelle durch Klicken-und-Ziehen einsortiert werden. Dies kann einerseits dazu verwendet werden, um Bereiche innerhalb einer Kategorie zu sortieren, andererseits können Bereiche in andere Kategorien verschoben werden.', 'BR', 0, 'HTML #plugins #layout_wrapper #layout_page #layout_container #layout_content #forum #sortable_areas TABLE TBODY #tutorArea TD IMG#tutorMoveArea.handle.js :eq(1)', 'plugins.php/coreforum', '', 1405424379),
('44f859c50648d3410c39207048ddd833', 5, 'Neuen Bereich hinzufügen', 'Hier können neue Bereiche zu einer Kategorie hinzugefügt werden.', 'BR', 0, 'TFOOT TR TD A SPAN', 'plugins.php/coreforum', '', 1405424421),
('44f859c50648d3410c39207048ddd833', 6, 'Neue Kategorie erstellen', 'Hier kann eine neue Kategorie im Forum erstellt werden. Geben Sie hierfür den Titel der neuen Kategorie ein.', 'TL', 0, '#tutorAddCategory H2', 'plugins.php/coreforum', '', 1405424458),
('ef5092ba722c81c37a5a6bd703890bd9', 1, 'Was ist Blubbern?', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen von \"Blubber\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'plugins.php/blubber/streams/global', '', 1405507364),
('ef5092ba722c81c37a5a6bd703890bd9', 2, 'Beitrag erstellen', 'Hier kann eine Diskussion durch Schreiben von Text begonnen werden. Absätze lassen sich durch Drücken von Umschalt+Eingabe erzeugen. Der Text wird durch Drücken von Eingabe abgeschickt.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/global', '', 1405507478),
('ef5092ba722c81c37a5a6bd703890bd9', 8, 'Beitrag ändern', 'Wird der Mauszeiger auf einem beliebigen Beitrag positioniert, erscheint dessen Datum. Bei eigenen Beiträgen erscheint außerdem rechts neben dem Datum ein Icon, mit dem der Beitrag nachträglich geändert werden kann.', 'BR', 0, 'DIV DIV A SPAN.time', 'plugins.php/blubber/streams/global', '', 1405507901),
('ef5092ba722c81c37a5a6bd703890bd9', 9, 'Beitrag verlinken', 'Wird der Mauszeiger auf dem ersten Diskussionsbeitrag positioniert, erscheint links neben dem Datum ein Link-Icon. Wenn dieses mit der rechten Maustaste angeklickt wird, kann der Link auf diesen Beitrag kopiert werden, um ihn an anderer Stelle einfügen zu können.', 'BR', 0, 'DIV DIV A.permalink', 'plugins.php/blubber/streams/global', '', 1405508281),
('ef5092ba722c81c37a5a6bd703890bd9', 3, 'Text gestalten', 'Der Text kann formatiert und mit Smileys versehen werden.\r\nEs können die üblichen Formatierungen verwendet werden, wie z. B. **fett** oder %%kursiv%%.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/global', '', 1405508371),
('ef5092ba722c81c37a5a6bd703890bd9', 5, 'Datei hinzufügen', 'Dateien können in einen Beitrag eingefügt werden, indem sie per Drag&Drop in ein Eingabefeld gezogen werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/global', '', 1405508401),
('ef5092ba722c81c37a5a6bd703890bd9', 6, 'Schlagworte', 'Beiträge können mit Schlagworten (engl. \"Hashtags\") versehen werden, indem einem beliebigen Wort des Beitrags ein # vorangestellt wird.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/global', '', 1405508442),
('ef5092ba722c81c37a5a6bd703890bd9', 7, 'Schlagwortwolke', 'Durch Anklicken eines Schlagwortes werden alle Beiträge aufgelistet, die dieses Schlagwort enthalten.', 'RT', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(1)', 'plugins.php/blubber/streams/global', '', 1405508505),
('3a717a468afb0822cb1455e0ae6b6fce', 9, 'Beitrag verlinken', 'Wird der Mauszeiger auf dem ersten Diskussionsbeitrag positioniert, erscheint links neben dem Datum ein Link-Icon. Wenn dieses mit der rechten Maustaste angeklickt wird, kann der Link auf diesen Beitrag kopiert werden, um ihn an anderer Stelle einfügen zu können.', 'BR', 0, 'DIV DIV A.permalink', 'plugins.php/blubber/streams/profile', '', 1405508281),
('6849293baa05be5bef8ff438dc7c438b', 1, 'Suche', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen der \"Suche\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'dispatch.php/search/courses', '', 1405519865),
('6849293baa05be5bef8ff438dc7c438b', 2, 'Suchbegriff eingeben', 'In dieses Eingabefeld kann ein Suchbegriff (wie z.B. der Veranstaltungsname, Dozent) eingegeben werden.', 'B', 0, 'INPUT#search_sem_quick_search_1.ui-autocomplete-input', 'dispatch.php/search/courses', '', 1405520106),
('6849293baa05be5bef8ff438dc7c438b', 3, 'Semesterauswahl', 'Durch einen Klick auf das Drop-Down Menü kann bestimmt werden, auf welches Semester sich der Suchbegriff beziehen soll. \r\n\r\nStandardgemäß ist das aktuelle Semester eingestellt.', 'TL', 0, 'SELECT#search_sem_sem', 'dispatch.php/search/courses', '', 1405520208),
('6849293baa05be5bef8ff438dc7c438b', 5, 'Erweiterte Suche', 'Mit der Erweiterten Suche kann die Suche um weitere Optionen erweitert werden.', 'R', 0, 'A.options-checkbox.options-unchecked', 'dispatch.php/search/courses', '', 1405520436),
('6849293baa05be5bef8ff438dc7c438b', 6, 'Schnellsuche', 'Die Schnellsuche ist auch auf anderen Seiten von Stud.IP jederzeit verfügbar. Nach der Eingabe eines Stichwortes, wird mit \"Enter\" bestätigt, oder auf die Lupe rechts neben dem Feld geklickt.', 'B', 0, 'INPUT#search_sem_quick_search_2.quicksearchbox.ui-autocomplete-input', 'dispatch.php/search/courses', '', 1405520634),
('6849293baa05be5bef8ff438dc7c438b', 7, 'Weitere Suchmöglichkeiten', 'Neben Veranstaltungen besteht auch die Möglichkeit, im Archiv, nach Personen, nach Einrichtungen oder nach Ressourcen zu suchen.', 'R', 0, '#nav_search_resources A SPAN', 'dispatch.php/search/courses', '', 1405520751),
('b74f8459dce2437463096d56db7c73b9', 1, 'Hilfe-Tour \"Meine Veranstaltungen\"', 'Diese Tour gibt einen Überblick über die wichtigsten Funktionen der Seite \"Meine Veranstaltungen\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'dispatch.php/my_courses', '', 1405521184),
('b74f8459dce2437463096d56db7c73b9', 2, 'Veranstaltungsüberblick', 'Hier werden die  Veranstaltungen des aktuellen und vergangenen Semesters angezeigt. Neue Veranstaltungen erscheinen zunächst in rot.', 'T', 0, '#my_seminars TABLE THEAD TR TH :eq(2)', 'dispatch.php/my_courses', '', 1405521244),
('154e711257d4d32d865fb8f5fb70ad72', 1, 'Meine Dateien', 'Meine Dateien ist der persönliche Dateibereich. Hier können Dateien auf Stud.IP gespeichert werden, um sie von dort auf andere Rechner herunterladen zu können.\r\n\r\nAndere Studierende oder Lehrende erhalten keinen Zugriff auf Dateien, die in den persönlichen Dateibereich hochgeladen werden.\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'dispatch.php/document/files', '', 1405592884),
('154e711257d4d32d865fb8f5fb70ad72', 4, 'Dateiübersicht', 'Alle Dateien und Verzeichnisse werden tabellarisch aufgelistet. Neben dem Namen werden noch weitere Informationen wie der Dateityp oder die Dateigröße angezeigt.', 'TL', 0, '#layout_content FORM TABLE THEAD TR TH :eq(3)', 'dispatch.php/document/files', '', 1405593089),
('154e711257d4d32d865fb8f5fb70ad72', 3, 'Neue Dateien und Verzeichnisse', 'Hier können neue Dateien von dem Computer in den persönlichen Dateibereich hochgeladen und neue Verzeichnisse erstellt werden.', 'TL', 0, '#layout-sidebar SECTION DIV DIV UL LI A :eq(0)', 'dispatch.php/document/files', '', 1405593409),
('ef5092ba722c81c37a5a6bd703890bd9', 4, 'Personen erwähnen', 'Andere können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/global', '', 1405672301),
('154e711257d4d32d865fb8f5fb70ad72', 6, 'Export', 'Hier besteht die Möglichkeit einzelne Ordner oder den vollständigen Dateibereich als ZIP-Datei herunterzuladen. Darin sind alle Dateien und Verzeichnisse enthalten.', 'TL', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(1)', 'dispatch.php/document/files', '', 1405593708),
('154e711257d4d32d865fb8f5fb70ad72', 5, 'Aktionen', 'Bereits hochgeladene Dateien und Ordner können hier bearbeitet, heruntergeladen, verschoben, kopiert und gelöscht werden.', 'TR', 0, '#layout_content FORM TABLE THEAD TR TH :eq(7)', 'dispatch.php/document/files', '', 1405594079),
('154e711257d4d32d865fb8f5fb70ad72', 2, 'Verfügbarer Speicherplatz', 'Der Speicherplatz des persönlichen Dateibereichs ist begrenzt. Es wird angezeigt, wie viel Speicherplatz noch verfügbar ist.', 'BR', 0, 'DIV.caption-actions', 'dispatch.php/document/files', '', 1405594184),
('edfcf78c614869724f93488c4ed09582', 5, 'Rundmail an Nutzergruppe versenden', 'Weiterhin besteht die Möglichkeit eine Rundmail an einzelne Nutzergruppen zu versenden.', 'BR', 0, '#layout_container #layout_content TABLE CAPTION SPAN A IMG :eq(0)', 'dispatch.php/course/members', '', 1406637123),
('25e7421f286fc5bdf9e41beadb484ffa', 4, 'Voraussetzungen', 'Eine Bilddatei muss im **.jpg**, **.png** oder **.gif** Format vorliegen.\r\nDie Dateigröße darf 700 KB nicht überschreiten.', 'L', 0, '#layout_content #edit_avatar TBODY TR TD FORM B :eq(2)', 'dispatch.php/settings/avatar', '', 1406722657),
('19ac063e8319310d059d28379139b1cf', 1, 'Studiengruppe anlegen', 'Studiengruppen ermöglichen die Zusammenarbeit mit anderen. Diese Tour gibt Ihnen einen Überblick darüber wie Sie Studiengruppen anlegen können.\r\n\r\nUm zum nächsten Schritt zu gelangen, klicken Sie bitte rechts unten auf \"Weiter\".', 'R', 0, '', 'dispatch.php/my_studygroups', '', 1405684423),
('19ac063e8319310d059d28379139b1cf', 2, 'Studiengruppe anlegen', 'Mit Klick auf \"Neue Studiengruppe anlegen\" kann eine neue Studiengruppe angelegt werden.', 'R', 0, 'A#nav_browse_new', 'dispatch.php/my_studygroups', '', 1406017730),
('19ac063e8319310d059d28379139b1cf', 3, 'Studiengruppe benennen', 'Der Name einer Studiengruppe sollte aussagekräftig sein und einmalig im gesamten Stud.IP.', 'R', 0, 'INPUT#groupname', 'dispatch.php/course/studygroup/new', '', 1405684720),
('19ac063e8319310d059d28379139b1cf', 4, 'Beschreibung hinzufügen', 'Die Beschreibung ermöglicht es weitere Informationen anzuzeigen und somit das Auffinden der Gruppe zu erleichtern.', 'R', 0, 'TEXTAREA#groupdescription', 'dispatch.php/course/studygroup/new', '', 1405684806),
('19ac063e8319310d059d28379139b1cf', 8, 'Studiengruppe speichern', 'Nach dem Speichern einer Studiengruppe erscheint diese unter \"Veranstaltungen > Meine Studiengruppen\".', 'L', 0, '#layout_content FORM TABLE TBODY TR TD :eq(14)', 'dispatch.php/course/studygroup/new', '', 1405686068),
('19ac063e8319310d059d28379139b1cf', 5, 'Inhaltselemente zuordnen', 'Hier können Inhaltselemente aktiviert werden, welche  innerhalb der Studiengruppe zur Verfügung stehen sollen. Das Fragezeichen gibt nähere Informationen zur Bedeutung der einzelnen Inhaltselemente.', 'L', 0, '#layout_content FORM TABLE TBODY TR TD :eq(5)', 'dispatch.php/course/studygroup/new', '', 1405685093),
('19ac063e8319310d059d28379139b1cf', 6, 'Zugang festlegen', 'Mit diesem Drop-down-Menü kann der Zugang zur Studiengruppe eingeschränkt werden.\r\n\r\nBeim Zugang \"offen für alle\" können sich alle Studierenden frei eintragen und an der Gruppe beteiligen.\r\n\r\nBeim Zugang \"Auf Anfrage\" müssen Teilnehmer durch den Gruppengründer hinzugefügt werden.', 'R', 0, 'SELECT#groupaccess', 'dispatch.php/course/studygroup/new', '', 1405685334),
('19ac063e8319310d059d28379139b1cf', 7, 'Nutzungsbedingungen akzeptieren', 'Bei der Erstellung einer Studiengruppe müssen die Nutzungsbedingungen akzeptiert werden.', 'R', 0, 'P LABEL', 'dispatch.php/course/studygroup/new', '', 1405685652),
('edfcf78c614869724f93488c4ed09582', 6, 'Gruppen erstellen', 'Hier können die Teilnehmenden der Veranstaltung in Gruppen eingeteilt werden.', 'R', 0, 'A#nav_course_edit_groups', 'dispatch.php/course/members', '', 1405689311),
('b74f8459dce2437463096d56db7c73b9', 3, 'Veranstaltungsdetails', 'Mit Klick auf das \"i\" erscheint ein Fenster mit den wichtigsten Eckdaten der Veranstaltung.', 'T', 0, '#my_seminars TABLE THEAD TR TH :eq(3)', 'dispatch.php/my_courses', '', 1405931069),
('edfcf78c614869724f93488c4ed09582', 7, 'Gruppe benennen', 'Sie können in den Vorlagen nach einem passenden Gruppennamen suchen und ihn mit dem gelben Doppelpfeil auswählen. Alternativ haben Sie auch die Möglichkeit, einen neuen Gruppennamen zu bestimmen, indem Sie im rechten Feld den Namen direkt eintragen.', 'B', 0, 'SELECT', 'admin_statusgruppe.php', '', 1405689541),
('edfcf78c614869724f93488c4ed09582', 1, 'Teilnehmerverwaltung', 'Diese Tour gibt einen Überblick über die Teilnehmerverwaltung einer Veranstaltung.\r\n\r\nUm zum nächsten Schritt zu gelangen, klicken Sie bitte rechts unten auf \"Weiter\".', 'B', 0, '', 'dispatch.php/course/members', '', 1405688399),
('edfcf78c614869724f93488c4ed09582', 2, 'Personen eintragen', 'Mit diesen Funktionen können entweder einzelne Personen in Stud.IP gesucht und direkt als Lehrende, Tutor/-in oder Studierende eintragen werden. Es ist auch möglich eine Teilnehmerliste einzugeben, um viele Personen auf einmal als Tutor/-in der Veranstaltung zuzuordnen.', 'R', 0, '#layout-sidebar SECTION DIV.sidebar-widget :eq(1)', 'dispatch.php/course/members', '', 1405688707),
('edfcf78c614869724f93488c4ed09582', 4, 'Rundmail verschicken', 'Hier kann eine Rundmail an alle Teilnehmende der Veranstaltung verschickt werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV UL LI A :eq(3)', 'dispatch.php/course/members', '', 1406636964),
('edfcf78c614869724f93488c4ed09582', 8, 'Gruppengröße', 'Mit dem Feld \"Gruppengröße\" können Sie die maximale Anzahl der Teilnehmer einer Gruppe festlegen. Wenn Sie dies nicht benötigen, lassen Sie das Feld einfach leer.', 'B', 0, 'INPUT#role_size', 'admin_statusgruppe.php', '', 1405689763),
('edfcf78c614869724f93488c4ed09582', 9, 'Selbsteintrag', 'Wenn Sie die Funktion \"Selbsteintrag\" aktivieren, können sich die Teilnehmenden der Veranstaltung selbst in die Gruppen eintragen.', 'B', 0, 'INPUT#self_assign', 'admin_statusgruppe.php', '', 1405689852),
('edfcf78c614869724f93488c4ed09582', 10, 'Dateiordner', 'Wenn Sie die Funktion \"Dateiordner\" aktivieren, wird zusätzlich ein Dateiordner pro Gruppe neu angelegt. In diesen Ordner können gruppenspezifische Dateien hochgeladen werden.', 'B', 0, 'INPUT#group_folder', 'admin_statusgruppe.php', '', 1405689936),
('edfcf78c614869724f93488c4ed09582', 3, 'Hochstufen / Herabstufen', 'Um eine bereits eingetragene Person zum/zur Tutor/-in hochzustufen oder zum/zur LeserIn herabzustufen, wählen Sie diese Person in der Liste aus und führen Sie mit Hilfe des Dropdown-Menü die gewünschte Aktion aus.', 'T', 0, '#autor CAPTION', 'dispatch.php/course/members', '', 1405690324),
('3a717a468afb0822cb1455e0ae6b6fce', 7, 'Schlagwortwolke', 'Durch Anklicken eines Schlagwortes werden alle Beiträge aufgelistet, die dieses Schlagwort enthalten.', 'RT', 0, 'DIV.sidebar-widget-header', 'plugins.php/blubber/streams/profile', '', 1405508505),
('b74f8459dce2437463096d56db7c73b9', 4, 'Veranstaltungsinhalte', 'Hier werden alle Inhalte (wie z.B. ein Forum) durch entsprechende Symbole angezeigt.\r\nFalls es seit dem letzten Login Neuigkeiten gab, erscheinen diese in rot.', 'LT', 0, '#my_seminars TABLE THEAD TR TH :eq(4)', 'dispatch.php/my_courses', '', 1405931225),
('b74f8459dce2437463096d56db7c73b9', 5, 'Verlassen der Veranstaltung', 'Ein Klick auf das Tür-Icon ermöglicht eine direkte Austragung aus der Veranstaltung.', 'TR', 0, '#my_seminars TABLE THEAD TR TH :eq(5)', 'dispatch.php/my_courses', '', 1405931272),
('b74f8459dce2437463096d56db7c73b9', 6, 'Zugriff auf archivierte Veranstaltungen', 'Falls Veranstaltungen archiviert sind, kann hier auf diese zugegriffen werden.', 'RT', 0, 'A#nav_browse_archive', 'dispatch.php/my_courses', '', 1405931431),
('3a717a468afb0822cb1455e0ae6b6fce', 2, 'Beitrag erstellen', 'Hier kann eine Diskussion durch Schreiben von Text begonnen werden. Absätze lassen sich durch Drücken von Umschalt+Eingabe erzeugen. Der Text wird durch Drücken von Eingabe abgeschickt.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/profile', '', 1405507478),
('b74f8459dce2437463096d56db7c73b9', 7, 'Anpassung der Veranstaltungsansicht', 'Zur Anpassung der Veranstaltungsübersicht, kann man die Veranstaltungen nach bestimmten Kriterien (wie z.B. Studienbereiche, Dozenten oder Farben) gliedern.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(2)', 'dispatch.php/my_courses', '', 1405932131),
('b74f8459dce2437463096d56db7c73b9', 8, 'Zugriff auf Veranstaltung vergangener und zukünftiger Semester', 'Durch Klick auf das Drop-Down Menü können beispielsweise Veranstaltung aus vergangenen Semestern angezeigt werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(3)', 'dispatch.php/my_courses', '', 1405932230),
('b74f8459dce2437463096d56db7c73b9', 9, 'Weitere mögliche Aktionen', 'Hier können Sie alle Neuigkeiten als gelesen markieren, Farbgruppierungen nach Belieben ändern oder\r\nauch die Benachrichtigungen über Aktivitäten in den einzelnen Veranstaltungen anpassen.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(1)', 'dispatch.php/my_courses', '', 1405932320),
('977f41c5c5239c4e86f04c3df27fae38', 1, 'Willkommen im neuen Stud.IP 3.1', 'Dies ist eine Hilfe-Tour, die die wichtigsten Neuerungen in Stud.IP vorstellt. \r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\". Eine Hilfe-Tour kann jederzeit durch einen Klick auf \"Beenden\" beendet werden.', 'TL', 0, '', 'dispatch.php/start', '', 1405932373),
('977f41c5c5239c4e86f04c3df27fae38', 2, 'Hilfelasche', 'Auf jeder Seite findet sich die Hilfe von nun an in der sogenannten Hilfelasche. Diese öffnet sich mit einem Klick auf das Fragezeichen. \r\n\r\nHier findet sich kurz und knapp zu jeder Seite die wichtigsten Informationen, Links zur ausführlichen Hilfeseite mit Anleitungsvideos und gegebenenfalls Hilfe-Touren.', 'BR', 0, 'DIV.helpbar-container .helpbar-title', 'dispatch.php/start', '', 1405932475),
('977f41c5c5239c4e86f04c3df27fae38', 3, 'Gliederung der Startseite', 'Die Startseite im neuen Stud.IP ist standardmäßig so gegliedert wie die alte Version. Neu ist, dass jedes Element (\"Widget\") individuell entfernt und verschoben werden kann. Darüber hinaus können noch weitere Widgets hinzugefügt werden. Hierzu gibt es eine separate Hilfe-Tour und die Hinweise in der Hilfe.', 'TL', 0, '', 'dispatch.php/start', '', 1405932516),
('b74f8459dce2437463096d56db7c73b9', 10, 'Studiengruppen und Einrichtungen', 'Es besteht zudem die Möglichkeit auf persönliche Studiengruppen oder Einrichtungen zuzugreifen.', 'R', 0, '#nav_browse_my_institutes A', 'dispatch.php/my_courses', '', 1405932519),
('977f41c5c5239c4e86f04c3df27fae38', 4, 'Sidebar', 'Auf allen Seiten ist nun links die Sidebar positioniert. Sie enthält Funktionen für die aktuelle Seite.\r\nIm alten Stud.IP gab es mit der Infobox auf der rechten Seite etwas Ähnliches.', 'R', 0, 'SECTION.sidebar', 'dispatch.php/start', '', 1405932633),
('977f41c5c5239c4e86f04c3df27fae38', 5, 'Änderung der Navigation', 'Häufig ist die Reiternavigation vom alten Stud.IP nun in der Sidebar zu finden. Auf dieser Seite sind das zum Beispiel die Punkte \"Neue Nachricht schreiben\" und der Gesendet-Ordner.', 'R', 0, 'SECTION.sidebar ', 'dispatch.php/messages/overview', '', 1405932671),
('977f41c5c5239c4e86f04c3df27fae38', 6, 'Studiengruppen und Einrichtungen', 'Die Einrichtungen, die früher unter den Veranstaltungen standen und die Studiengruppen, die früher zwischen den Veranstaltungen standen, finden sich nun in eigenen Reitern wieder.', 'R', 0, '#nav_browse_my_institutes A SPAN', 'dispatch.php/my_courses', '', 1405932830),
('977f41c5c5239c4e86f04c3df27fae38', 7, 'Hinweise zu den Anmeldeverfahren', 'Im neuen Stud.IP haben sich die Zugangsberechtigungen und Anmeldeverfahren geändert. Das betrifft sowohl Studierende als auch Lehrende. Hierzu gibt es separate Feature-Touren und die Hinweise in der Hilfe.', 'TL', 0, '', 'dispatch.php/my_courses', '', 1405932890),
('3a717a468afb0822cb1455e0ae6b6fce', 1, 'Was ist Blubbern?', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen von \"Blubber\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'plugins.php/blubber/streams/profile', '', 1405507364),
('3a717a468afb0822cb1455e0ae6b6fce', 6, 'Schlagworte', 'Beiträge können mit Schlagworten (engl. \"Hashtags\") versehen werden, indem einem beliebigen Wort des Beitrags ein # vorangestellt wird.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/profile', '', 1405508442),
('49604a77654617a745e29ad6b253e491', 1, 'Funktionen und Gestaltungs-möglichkeiten der Startseite', '\r\nDiese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen der \"Startseite\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'dispatch.php/start', '', 1405934926),
('49604a77654617a745e29ad6b253e491', 2, 'Individuelle Gestaltung der Startseite', 'Die Startseite ist standardmäßig so konfiguriert, dass die Elemente \"Schnellzugriff\", \"Ankündigungen\", \"Meine aktuellen Termine\" und  \"Umfragen\" angezeigt werden. Die Elemente werden Widgets genannt und  können entfernt, hinzugefügt und verschoben werde.n Jedes Widget kann individuell hinzugefügt, entfernt und verschoben werden.', 'TL', 0, '', 'dispatch.php/start', '', 1405934970),
('49604a77654617a745e29ad6b253e491', 3, 'Widget hinzufügen', 'Hier können Widgets hinzugefügt werden. Zusätzlich zu den Standard-Widgets kann beispielsweise der persönliche Stundenplan auf der Startseite anzeigt werden. Neu hinzugefügte Widgets erscheinen ganz unten auf der Startseite. Darüber hinaus kann in der Sidebar direkt zu jedem Widget gesprungen werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV UL LI :eq(4)', 'dispatch.php/start', '', 1405935192),
('49604a77654617a745e29ad6b253e491', 5, 'Widget positionieren', 'Ein Widget kann per Drag&Drop an die gewünschte Position verschoben werden: Dazu wird in die Titelzeile eines Widgets geklickt, die Maustaste gedrückt gehalten und das Widget an die gewünschte Position gezogen.', 'B', 0, '.widget-header', 'dispatch.php/start', '', 1405935687),
('49604a77654617a745e29ad6b253e491', 7, 'Widget entfernen', 'Jedes Widget kann durch Klicken auf das X in der rechten oberen Ecke entfernt werden. Bei Bedarf kann es jederzeit wieder hinzugefügt werden.', 'R', 0, '.widget-header', 'dispatch.php/start', '', 1405935376),
('49604a77654617a745e29ad6b253e491', 6, 'Widget bearbeiten', 'Bei einigen Widgets wird neben dem X zum Schließen noch ein weiteres Symbol angezeigt. Der Schnellzugriff bspw. kann durch Klick auf diesen Button individuell angepasst, die Ankündigungen können abonniert und bei den aktuellen Terminen bzw. Stundenplan können Termine hinzugefügt werden.', 'L', 0, '#layout_content DIV UL DIV SPAN A IMG :eq(0)', 'dispatch.php/start', '', 1405935792),
('3629493a16bf2680de64361f07cab096', 1, 'Was ist Blubbern?', 'Diese Tour gibt Ihnen einen Überblick über die wichtigsten Funktionen von \"Blubber\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'plugins.php/blubber/streams/forum', '', 1405507364),
('3a717a468afb0822cb1455e0ae6b6fce', 4, 'Personen erwähnen', 'Andere können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/profile', '', 1405672301),
('3629493a16bf2680de64361f07cab096', 2, 'Beitrag erstellen', 'Hier kann eine Diskussion durch Schreiben von Text begonnen werden. Absätze lassen sich durch Drücken von Umschalt+Eingabe erzeugen. Der Text wird durch Drücken von Eingabe abgeschickt.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/forum', '', 1405507478),
('7cccbe3b22dfa745c17cb776fb04537c', 1, 'Hilfe-Tour \"Meine Veranstaltung\"', 'Diese Tour gibt einen Überblick über die wichtigsten Funktionen der Seite \"Meine Veranstaltungen\".\r\n\r\nUm auf den nächsten Schritt zu kommen, klicken Sie bitte rechts unten auf \"Weiter\".', 'TL', 0, '', 'dispatch.php/my_courses', '', 1406125847),
('7cccbe3b22dfa745c17cb776fb04537c', 2, 'Veranstaltungsüberblick', 'Hier werden die  Veranstaltungen des aktuellen und vergangenen Semesters angezeigt. Neue Veranstaltungen erscheinen zunächst in rot.', 'TL', 0, '#my_seminars TABLE THEAD TR TH :eq(2)', 'dispatch.php/my_courses', '', 1406125908),
('7cccbe3b22dfa745c17cb776fb04537c', 3, 'Veranstaltungsdetails', 'Mit Klick auf das \"i\" erscheint ein Fenster mit den wichtigsten Eckdaten der Veranstaltung.', 'T', 0, '#my_seminars TABLE THEAD TR TH :eq(3)', 'dispatch.php/my_courses', '', 1406125992),
('7cccbe3b22dfa745c17cb776fb04537c', 4, 'Veranstaltungsinhalte', 'Hier werden alle Inhalte (wie z.B. ein Forum) durch entsprechende Symbole angezeigt.\r\nFalls es seit dem letzten Login Neuigkeiten gab, erscheinen diese in rot.', 'LT', 0, '#my_seminars TABLE THEAD TR TH :eq(4)', 'dispatch.php/my_courses', '', 1406126049),
('7cccbe3b22dfa745c17cb776fb04537c', 5, 'Bearbeitung oder Löschung einer Veranstaltung', 'Der Klick auf das Zahnrad ermöglicht die Bearbeitung einer Veranstaltung.\r\nFalls bei einer Veranstaltung Teilnehmerstatus besteht, kann hier eine Austragung, durch Klick auf dasTür-Icon, vorgenommen werden.', 'TR', 0, '#my_seminars TABLE THEAD TR TH :eq(5)', 'dispatch.php/my_courses', '', 1406126134),
('3a717a468afb0822cb1455e0ae6b6fce', 8, 'Beitrag ändern', 'Wird der Mauszeiger auf einem beliebigen Beitrag positioniert, erscheint dessen Datum. Bei eigenen Beiträgen erscheint außerdem rechts neben dem Datum ein Icon, mit dem der Beitrag nachträglich geändert werden kann.', 'BR', 0, 'DIV DIV A SPAN.time', 'plugins.php/blubber/streams/profile', '', 1405507901),
('7cccbe3b22dfa745c17cb776fb04537c', 6, 'Anpassung der Veranstaltungsansicht', 'Zur Anpassung der Veranstaltungsübersicht, kann man die Veranstaltungen nach bestimmten Kriterien (wie z.B. Studienbereiche, Dozenten oder Farben) gliedern.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(2)', 'dispatch.php/my_courses', '', 1406126281),
('7cccbe3b22dfa745c17cb776fb04537c', 7, 'Zugriff auf Veranstaltung vergangener und zukünftiger Semester', 'Durch Klick auf das Drop-Down Menü können beispielsweise Veranstaltung aus vergangenen Semestern angezeigt werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(3)', 'dispatch.php/my_courses', '', 1406126316),
('7cccbe3b22dfa745c17cb776fb04537c', 8, 'Weitere mögliche Aktionen', 'Hier können Sie alle Neuigkeiten als gelesen markieren, Farbgruppierungen nach Belieben ändern oder\r\nauch die Benachrichtigungen über Aktivitäten in den einzelnen Veranstaltungen anpassen.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(1)', 'dispatch.php/my_courses', '', 1406126374),
('7cccbe3b22dfa745c17cb776fb04537c', 9, 'Studiengruppen und Einrichtungen', 'Es besteht zudem die Möglichkeit auf persönliche Studiengruppen oder Einrichtungen zuzugreifen.', 'R', 0, '#nav_browse_my_institutes A', 'dispatch.php/my_courses', '', 1406126415),
('3a717a468afb0822cb1455e0ae6b6fce', 5, 'Datei hinzufügen', 'Dateien können in einen Beitrag eingefügt werden, indem sie per Drag&Drop in ein Eingabefeld gezogen werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/profile', '', 1405508401),
('977f41c5c5239c4e86f04c3df27fae38', 8, 'Ende der Feature-Tour', 'Durch Klick auf \"Beenden\" in der Box rechts unten wird diese Tour beendet. Über die Hilfelasche lässt sich diese Tour jederzeit wieder starten.', 'TL', 0, '', 'dispatch.php/start', '', 1406539532),
('49604a77654617a745e29ad6b253e491', 4, 'Sprungmarken', 'Darüber hinaus kann mit Sprungmarken direkt zu jedem Widget gesprungen werden.', 'R', 0, '#layout-sidebar SECTION DIV DIV.sidebar-widget-header :eq(0)', 'dispatch.php/start', '', 1406623464),
('3629493a16bf2680de64361f07cab096', 5, 'Datei hinzufügen', 'Dateien können in einen Beitrag eingefügt werden, indem sie per Drag&Drop in ein Eingabefeld gezogen werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/forum', '', 1405508401),
('3629493a16bf2680de64361f07cab096', 6, 'Schlagworte', 'Beiträge können mit Schlagworten (engl. \"Hashtags\") versehen werden, indem einem beliebigen Wort des Beitrags ein # vorangestellt wird.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/forum', '', 1405508442),
('3629493a16bf2680de64361f07cab096', 7, 'Schlagwortwolke', 'Durch Anklicken eines Schlagwortes werden alle Beiträge aufgelistet, die dieses Schlagwort enthalten.', 'RT', 0, 'DIV.sidebar-widget-header', 'plugins.php/blubber/streams/forum', '', 1405508505),
('3629493a16bf2680de64361f07cab096', 4, 'Personen erwähnen', 'Andere können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden.', 'BL', 0, 'TEXTAREA#new_posting.autoresize', 'plugins.php/blubber/streams/forum', '', 1405672301);
";
        DBManager::get()->exec($query);

        // add settings
        $query = "INSERT IGNORE INTO `help_tour_settings` (`tour_id`, `active`, `access`) VALUES
('96ea422f286fb5bbf9e41beadb484a9a', 1, 'standard'),
('25e7421f286fc5bdf9e41beadb484ffa', 1, 'standard'),
('3a717a468afb0822cb1455e0ae6b6fce', 1, 'standard'),
('21f487fa74e3bfc7789886f40fe4131a', 1, 'standard'),
('44f859c50648d3410c39207048ddd833', 1, 'standard'),
('ef5092ba722c81c37a5a6bd703890bd9', 1, 'standard'),
('6849293baa05be5bef8ff438dc7c438b', 1, 'standard'),
('b74f8459dce2437463096d56db7c73b9', 1, 'standard'),
('154e711257d4d32d865fb8f5fb70ad72', 1, 'standard'),
('19ac063e8319310d059d28379139b1cf', 1, 'standard'),
('edfcf78c614869724f93488c4ed09582', 1, 'standard'),
('977f41c5c5239c4e86f04c3df27fae38', 0, 'autostart_once'),
('49604a77654617a745e29ad6b253e491', 1, 'standard'),
('3629493a16bf2680de64361f07cab096', 1, 'standard'),
('7cccbe3b22dfa745c17cb776fb04537c', 1, 'standard');
";
        DBManager::get()->exec($query);
    }

    function addHelpContent() {
        $query = "INSERT IGNORE INTO `help_content` (`content_id`, `language`, `label`, `icon`, `content`, `route`, `studip_version`, `position`, `custom`, `visible`, `author_id`, `installation_id`, `mkdate`) VALUES
('5a90d1219dbeb07c124156592fb5d877', 'de', '', '', 'In den allgemeinen Einstellungen können verschiedene Anzeigeoptionen und Benachrichtigungsfunktionen ausgewählt und verändert werden.', 'dispatch.php/settings/general', '3.1', 0, 0, 1, '', '', 1406641688),
('a202eb75df0a1da2a309ad7a4abfac59', 'de', '', '', 'In den Privatsphäre-Einstellungen kann die Sichtbarkeit und Auffindbarkeit des eigenen Profils eingestellt werden.', 'dispatch.php/settings/privacy', '3.1', 0, 0, 1, '', '', 1406641688),
('845d1ce67a62d376ec26c8ffbb22d492', 'de', '', '', 'Die Einstellungen des Nachrichtensystems bieten die Möglichkeit z.B. eine Weiterleitung der in Stud.IP empfangenen Nachrichten an die E-Mail-Adresse zu veranlassen.', 'dispatch.php/settings/messaging', '3.1', 0, 0, 1, '', '', 1406641688),
('85cbaa1648af330cc4420b57df4be29c', 'de', '', '', 'Die Einstellungen des Terminkalenders bieten die Möglichkeit, diesen an eigene Bedürfnisse anzupassen.', 'dispatch.php/settings/calendar', '3.1', 0, 0, 1, '', '', 1406641688),
('1da144f3c6f52af0566c343151a6a6ff', 'de', '', '', 'In den Benachrichtigungseinstellungen kann ausgewählt werden, bei welchen Änderungen innerhalb einer Veranstaltung eine Benachrichtigung erfolgen soll.', 'dispatch.php/settings/notification', '3.1', 0, 0, 1, '', '', 1406641688),
('01ad8998268101ad186babf43dac30a4', 'de', '', '', 'In den Standard-Vertretungseinstellungen können Lehrende eine Standard-Vertretung festlegen, die alle Veranstaltungen des Lehrenden verwalten und ändern kann.', 'dispatch.php/settings/deputies', '3.1', 0, 0, 1, '', '', 1406641688),
('1c61657979ce22a9af023248a617f6b2', 'de', '', '', 'Die Startseite wird nach dem Einloggen angezeigt und kann an persönliche Bedürfnisse mit Hilfe von Widgets angepasst werden.', 'dispatch.php/start', '3.1', 0, 0, 1, '', '', 1406641688),
('74c1da86f33f5adfb43e10220bfad238', 'de', '', '', 'Die Veranstaltungsseite zeigt alle belegten Veranstaltungen (standardmäßig nur die der letzten beiden Semester), alle belegten Studiengruppen sowie alle Einrichtungen, denen man zugeordnet wurde. Die Anzeige lässt sich über Farbgruppierungen, Semesterfilter usw. anpassen.', 'dispatch.php/my_courses', '3.1', 0, 0, 1, '', '', 1406641688),
('437c83a27473ef8139b47198101067fb', 'de', '', '', 'Hier erscheinen archivierte Veranstaltungen, denen der Nutzer zugeordnet ist. Inhalte können nicht mehr verändert, jedoch hinterlegte Dateien als zip-Datei heruntergeladen werden.', 'dispatch.php/my_courses/archive', '3.1', 0, 0, 1, '', '', 1406641688),
('04457f9a66eab07618fe502d470a9711', 'de', '', '', 'In der Übersicht finden sich veranstaltungsbezogene Kurz- und Detail-Informationen, Ankündigungen, Termine und Umfragen.', 'dispatch.php/course/overview', '3.1', 0, 0, 1, '', '', 1406641688),
('1d1323471cf21637f51284f4e6f2d135', 'de', '', '', 'Detaillierte Informationen über die Veranstaltung werden angezeigt, wie z.B. die Veranstaltungsnummer, Zuordnungen, Lehrende, Tutor/-innen etc. In den Detail-Informationen ist unter Aktionen das Eintragen in eine Veranstaltung möglich.', 'dispatch.php/course/details', '3.1', 0, 0, 1, '', '', 1406641688),
('7f4a1f5e3dfe2a459cf0eb357667d91c', 'de', '', '', 'Mit den Verwaltungsfunktionen lassen sich die Eigenschaften der Veranstaltung nachträglich ändern. Unter Aktionen ist die Simulation der Studierendenansicht möglich.', 'dispatch.php/course/management', '3.1', 0, 0, 1, '', '', 1406641688),
('4698cafeb9823735c50fd3a1745950ba', 'de', '', '', 'In den Grunddaten können Titel, Beschreibung, Lehrende etc. geändert werden. Die Bearbeitung kann teilweise gesperrt sein, wenn Daten aus anderen Systemen (z.B. LSF/ UniVZ) übernommen werden.', 'dispatch.php/course/basicdata/view', '3.1', 0, 0, 1, '', '', 1406641688),
('5fab81bbd1e19949f304df08ea21ca1b', 'de', '', '', 'Mit der Bild-Hochladen-Funktion lässt sich das Bild der Veranstaltung ändern, was Studierenden bei der Unterscheidung von Veranstaltungen auf der Meine-Veranstaltungen-Seite helfen kann.', 'dispatch.php/course/avatar/update', '3.1', 0, 0, 1, '', '', 1406641688),
('19c2bc232075602bd39efd4b6623d576', 'de', '', '', 'Mit der Studienbereiche-Funktion kann die Veranstaltung einem Studienbereich zugeordnet werden. Die Bearbeitung kann gesperrt sein, wenn Daten aus anderen Systemen (z.B. LSF/ UniVZ) übernommen werden.', 'dispatch.php/course/study_areas/show', '3.1', 0, 0, 1, '', '', 1406641688),
('70274c459a69e34bbf520e690a8e472b', 'de', '', '', 'Mit der Zeiten/Räume-Funktion können die Semester-, Termin- und Raumangaben der Veranstaltung geändert werden. Die Bearbeitung kann gesperrt sein, wenn Daten aus anderen Systemen (z.B. LSF/ UniVZ) übernommen werden.', 'raumzeit.php', '3.1', 0, 0, 1, '', '', 1406641688),
('19d47b782ac5c8b8b21bd1f94858a0fa', 'de', '', '', 'Mit Zugangsberechtigungen (Anmeldeverfahren) lässt sich z.B. durch Passwörter, Zeitsteuerung und Personenbeschränkung der Zugang zu einer Veranstaltung regulieren.', 'dispatch.php/course/admission', '3.1', 0, 0, 1, '', '', 1406641688),
('e939ac70210674f49a36ac428167a9b8', 'de', '', '', 'Mit der Umfragen-und-Tests-Funktion lassen sich (zeitgesteuerte) Umfragen oder einzelne Multiple-/Single-Choice-Fragen für Veranstaltungen, Studiengruppen oder das Profil erstellen.', 'admin_vote.php', '3.1', 0, 0, 1, '', '', 1406641688),
('2689cecba24e021f05fcece5e4c96057', 'de', '', '', 'Mit der Evaluationen-Funktion lassen sich Befragungen mit Multiple-Choice, Likert- und Freitextfragen für Veranstaltungen, Studiengruppen, das eigene Profil oder Einrichtungen erstellen. Dabei können auch öffentliche Vorlagen anderer Personen verwendet werden. Es werden alle zukünftigen, laufenden und beendeten Evaluationen angezeigt.', 'admin_evaluation.php', '3.1', 0, 0, 1, '', '', 1406641688),
('194874212676ced8d45e1883da1ad456', 'de', '', '', 'Das Forum ist eine textbasierte, zeit- und ortsunabhängige Möglichkeit zum Austausch von Fragen, Meinungen und Erfahrungen. Beiträge können abonniert, exportiert, als Favoriten gekennzeichnet und editiert werden. Über die Navigation links können unterschieldiche Ansichten (z.B. Neue Beiträge seit letztem LogIn) gewählt werden.', 'plugins.php/coreforum', '3.1', 0, 0, 1, '', '', 1406641688),
('a20036992a06e97a984832626121d99a', 'de', '', '', 'Die Personenliste zeigt eine Liste der Teilnehmenden dieser Veranstaltung. Weitere Teilnehmende können von Lehrenden hinzugefügt, entfernt, herabgestuft, heraufgestuft oder selbstdefinierten Gruppen zugeordnet werden.', 'dispatch.php/course/members', '3.1', 0, 0, 1, '', '', 1406641688),
('d79ca3bc4a8251862339b1c934504a54', 'de', '', '', 'Hier werden die selbstdefinierten Gruppen angezeigt. An diese können Nachrichten versendet werden. Ein Klick auf die orangenen Pfeile vor dem Gruppenname ordnet Sie der Gruppe zu.', 'statusgruppen.php', '3.1', 0, 0, 1, '', '', 1406641688),
('e22701c71b4425fb5a95adf725866097', 'de', '', '', 'Hier können Gruppen erstellt und verwaltet werden. Wenn der Selbsteintrag aktiviert ist, können sich Personen selbst ein- und austragen.', 'admin_statusgruppe.php', '3.1', 0, 0, 1, '', '', 1406641688),
('aa77d5ee6e0f9a9e6f4a1bbabeaf4a7e', 'de', '', '', 'Die Anwesenheitsliste zeigt alle Sitzungstermine (Sitzung, Vorlesung, Übung, Praktikum) des Ablaufplans und ermöglicht das Eintragen von Studierenden durch die Lehrenden in Stud.IP sowie einen Export der Liste zur Übersicht oder als Grundlage handschriftlicher Eintragungen.', 'participantsattendanceplugin/show', '3.1', 0, 0, 1, '', '', 1406641688),
('ac7326260fd5ca4fa83c1154f2ffc7b9', 'de', '', '', 'Die Dateiverwaltung bietet die Möglichkeit zum Hochladen, Verlinken, Verwalten und Herunterladen von Dateien. ', 'folder.php', '3.1', 0, 0, 1, '', '', 1406641688),
('29c3bfa01ddbaaa998094d3ee975a06a', 'de', '', '', 'Der Ablaufplan zeigt Termine, Themen und Räume der Veranstaltung an. Einzelne Termine können bearbeitet werden, z.B. können Themen zu Terminen hinzugefügt werden.', 'dispatch.php/course/dates', '3.1', 0, 0, 1, '', '', 1406641688),
('c4dee277f741cfa7d5a65fa0c6bead4c', 'de', '', '', 'Hier können Termine mit Themen versehen werden oder bereits eingegebene Themen übernommen und bearbeitet werden.', 'dispatch.php/course/topics', '3.1', 0, 0, 1, '', '', 1406641688),
('c01725d6a3da568e1b07aee4e68a7e1f', 'de', '', '', 'Diese Seite ermöglicht das Hinterlegen von freien Informationen, Links etc.', 'dispatch.php/course/scm', '3.1', 0, 0, 1, '', '', 1406641688),
('be204bdd0fce91702f51597bf8428fba', 'de', '', '', 'Das Wiki ermöglicht ein gemeinsames, asynchrones Erstellen und Bearbeiten von Texten. Texte lassen sich formatieren und miteinander verknüpfen, so dass ein verzweigtes Nachschlagewerk entsteht. ', 'wiki.php', '3.1', 0, 0, 1, '', '', 1406641688),
('707b0db0e45fc3bab04be7eff38c1d32', 'de', '', '', 'Die Literaturseite bietet Lehrenden die Möglichkeit, Literaturlisten zu erstellen oder aus Literaturverwaltungsprogrammen zu importieren. Diese Listen können in Lehrveranstaltungen kopiert und sichtbar geschaltet werden. Je nach Anbindung kann im tatsächlichen Buchbestand der Hochschule recherchiert werden. ', 'dispatch.php/course/literature', '3.1', 0, 0, 1, '', '', 1406641688),
('8dd3b80d9f95218d67edc3cb570559ff', 'de', '', '', 'Hier lassen sich Literaturlisten bearbeiten und in der Veranstaltung sichtbar schalten (mit Klick auf das \"Auge\").', 'dispatch.php/literature/edit_list', '3.1', 0, 0, 1, '', '', 1406641688),
('e29098d188ae25c298d78978de50bf09', 'de', '', '', 'Hier kann in Katalogen nach Literatur gesucht und diese zur Merkliste hinzugefügt werden.', 'dispatch.php/literature/search', '3.1', 0, 0, 1, '', '', 1406641688),
('a1ea37130799a59f7774473f1a681141', 'de', '', '', 'Die Lernmodulschnittstelle ermöglicht es, Selbstlerneinheiten oder Tests aus externen Programmen wie ILIAS und LON-CAPA in Stud.IP zur Verfügung zu stellen.', 'dispatch.php/course/elearning/show', '3.1', 0, 0, 1, '', '', 1406641688),
('595c46d86f681f7da4bd2fae780db618', 'de', '', '', 'Wählen Sie das gewünschte System und anschließend das Lernmodul/ den Test aus. Schreibrechte bestimmen, wer zukünftig das Lernmodul bearbeiten darf. In der Sidebar befindet sich die Option \"Zuordnungen aktualisieren\", um geänderte Inhalte z.B. im ILIAS Kurs zu Stud.IP zu übertragen.', 'dispatch.php/course/elearning/edit', '3.1', 0, 0, 1, '', '', 1406641688),
('6529fd70b461fa4a9242e874fbf2a5d3', 'de', '', '', 'In DoIT! haben Lehrende die Möglichkeit, verschiedene Arten von Aufgaben zu stellen, inklusive Hochladen von Dateien, Multiple-Choice-Fragen und Peer Reviewing. Die Aufgabenbearbeitung kann zeitlich befristet werden und wahlweise in Gruppen erfolgen.', 'plugins.php/reloadedplugin/show', '3.1', 0, 0, 1, '', '', 1406641688),
('95ff3a2a68dae73bcb14a4a538a8e4b5', 'de', '', '', 'Blubbern ist eine Mischform aus Forum und Chat, bei dem Beiträge der Teilnehmenden in Echtzeit angezeigt werden. Andere können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden.', 'plugins.php/blubber/streams/forum', '3.1', 0, 0, 1, '', '', 1406641688),
('633dab120ce3969c42f33aeb3a59fcc1', 'de', '', '', 'Der Gruppenkalender bietet eine Übersicht über Veranstaltungstermine und personalisierte Zusatztermine für diese Veranstaltung. ', 'plugins.php/gruppenkalenderplugin/show', '3.1', 0, 0, 1, '', '', 1406641688),
('1058f03da5b6fc6a5ff3a08c9c1fa5f7', 'de', '', '', 'Hier können der Veranstaltung weitere Funktionen hinzugefügt werden.', 'dispatch.php/course/plus', '3.1', 0, 0, 1, '', '', 1406641688),
('8a1d7d04c70d93be44e8fe6a8e8c3443', 'de', '', '', 'Das Lerntagebuch unterstützt den selbstgesteuerten Lernprozess der Studierenden und wird von ihnen selbstständig geführt. Anfragen zu Arbeitsschritten an die Lehrenden sind möglich, bestimmte Daten können individualisiert freigegeben werden.', 'plugins.php/lerntagebuchplugin/overview', '3.1', 0, 0, 1, '', '', 1406641688),
('72cec29d985f3e6d7df2b5fabb7fe666', 'de', '', '', 'Konfiguation des Lerntagebuchs für Studierende und Anlegen eines Lerntagebuchs für die Lehrenden.', 'plugins.php/lerntagebuchplugin/admin_settings', '3.1', 0, 0, 1, '', '', 1406641688),
('2fcc672d91f2627ab5ca48499e8b1617', 'de', '', '', 'Möglichkeit zur Bereitstellung von Vorlesungsaufzeichnungen und Podcasts für Studierende der Veranstaltung (durch Verlinkung auf die Dateien auf dem Medienserver). ', 'plugins.php/mediacastsplugin/show', '3.1', 0, 0, 1, '', '', 1406641688),
('bd0770f9eef5c10fc211114ac35fbe9b', 'de', '', '', 'Diese Seite zeigt die Studiengruppen an, denen die/der NutzerIn zugeordnet ist. Studiengruppen sind eine einfache Möglichkeit, mit Mitstudierenden, KollegInnen und anderen zusammenzuarbeiten. Jede/r NutzerIn kann Studiengruppen anlegen oder nach ihnen suchen. Die Farbgruppierung kann individuell angepasst werden.', 'dispatch.php/my_studygroups', '3.1', 0, 0, 1, '', '', 1406641688),
('82a17a5f19d211268b1fa90a1ebe0894', 'de', '', '', 'Hier kann eine neue Studiengruppe angelegt werden. Jede/r Stud.IP-NutzerIn kann Studiengruppen anlegen und nach eigenen Bedürfnissen konfigurieren.', 'dispatch.php/course/studygroup/new', '3.1', 0, 0, 1, '', '', 1406641688),
('e03cec310c0a884aee80c2d1eea3a53e', 'de', '', '', 'Diese Seite zeigt alle Studiengruppen an, die in Stud.IP existieren. Studiengruppen sind eine einfache Möglichkeit, mit Mitstudierenden, KollegInnen und anderen zusammenzuarbeiten. Jede/r NutzerIn kann Studiengruppen anlegen oder nach ihnen suchen.', 'dispatch.php/studygroup/browse', '3.1', 0, 0, 1, '', '', 1406641688),
('f92b5422246f585f051de1a81602dd56', 'de', '', '', 'Hier können Name, Funktionen und Zugangsbeschränkung der Studiengruppe bearbeitet werden.', 'dispatch.php/course/studygroup/edit', '3.1', 0, 0, 1, '', '', 1406641688),
('1dca5b0b83f7bca92ec4add50d34b8c5', 'de', '', '', 'Hier können der Studiengruppe Mitglieder hinzugefügt und Nachrichten an diese versendet werden.', 'dispatch.php/course/studygroup/members', '3.1', 0, 0, 1, '', '', 1406641688),
('1f6e2f98affbffb1d12904355e9313e5', 'de', '', '', 'Diese Seite zeigt die Einrichtungen an, denen die/der NutzerIn zugeordnet ist.', 'dispatch.php/my_institutes', '3.1', 0, 0, 1, '', '', 1406641688),
('bf9eb8f2c3842865009342b89fd35476', 'de', '', '', 'Die Nachrichtenseite bietet einen Überblick über erhaltene, systeminterne Nachrichten, welche mit selbstgewählten Schlüsselwörtern (sog. Tags) versehen werden können, um sie später leichter wieder auffinden zu können.', 'dispatch.php/messages/overview', '3.1', 0, 0, 1, '', '', 1406641688),
('6acc653cfabd3a0d4433ff0ab417bf6a', 'de', '', '', 'Übersicht über gesendete, systeminterne Nachrichten, welche mit selbstgewählten Schlüsselwörtern (sog. Tags) versehen werden können, um sie später leichter wieder auffinden zu können. ', 'dispatch.php/messages/sent', '3.1', 0, 0, 1, '', '', 1406641688),
('690e6eff3e83a5f372ec99fc49cafeb2', 'de', '', '', 'Blubbern ist das Stud.IP Echtzeitforum, eine Mischform aus Forum und Chat. Andere können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden. Texte lassen sich formatieren und durch Smileys ergänzen.', 'plugins.php/blubber/streams/global', '3.1', 0, 0, 1, '', '', 1406641688),
('cd69b74cd46172785bf2147fb0582e3c', 'de', '', '', 'Hier kann ein benutzerdefinierter Blubber-Stream erstellt werden. Er besteht immer aus einer Sammlung von Beiträgen aus ausgewählten Veranstaltungen, Kontaktgruppen und Schlagwörten, die auf Basis einer Filterung noch weiter eingeschränkt werden können. Der neue benutzerdefinierte Stream findet sich nach dem Klick auf den Speichern-Button in der Navigation unter Globaler Stream.', 'plugins.php/blubber/streams/edit', '3.1', 0, 0, 1, '', '', 1406641688),
('394a45f94e1d84d3744027a5a69d9e3e', 'de', '', '', 'Auf dieser Seite lässt sich einsehen, welche Kontakte gerade online sind. Diesen Personen kann eine Nachricht geschickt werden. Das Klicken auf den Namen einer Person leitet zu deren Profil weiter.', 'dispatch.php/online', '3.1', 0, 0, 1, '', '', 1406641688),
('245ce01d7a0175ab0b977ae822821e9e', 'de', '', '', 'Diese Seite bietet die Möglichkeit Stud.IP-Nutzende in das eigene Adressbuch einzutragen und alle bereits im Adressbuch befindlichen Kontakte aufzulisten.', 'contact.php', '3.1', 0, 0, 1, '', '', 1406641688),
('752d441cd321b05c55c8a5d9aa48ddce', 'de', '', '', 'Auf dieser Seite können Kontakte aus dem Adressbuch in selbstdefinierte Gruppen sortiert werden.', 'contact_statusgruppen.php', '3.1', 0, 0, 1, '', '', 1406641688),
('94a193baa212abbc9004280a1498e724', 'de', '', '', 'Hier können Kontaktgruppen oder das gesamte Adressbuch exportiert werden, um sie in einem externen Programm importieren zu können.', 'contact_export.php', '3.1', 0, 0, 1, '', '', 1406641688),
('7ebdd278d06f9fc1d2659a54bb3171c1', 'de', '', '', 'Die Rangliste sortiert die Stud.IP-Nutzenden absteigend anhand ihrer Punktzahl. Die Punktzahl wächst mit den Aktivitäten in Stud.IP und repräsentiert so die Erfahrung der Nutzenden mit dem System. Indem das Kästchen links mit einem Haken versehen wird, wird der eigene Wert für andere NutzerInnen in der Rangliste sichtbar gemacht. In der Grundeinstellung ist der eigene Wert nicht öffentlich sichtbar.', 'dispatch.php/score', '3.1', 0, 0, 1, '', '', 1406641688),
('82537b14dd3714ec9636124ed5af3272', 'de', '', '', 'Die Profilseite ermöglicht die Änderung der eigenen perönlichen Angaben inkl. Profilbild und Kategorien. Ähnlich wie in Facebook können Kommentare hinterlassen werden. Das Profil von Lehrenden enthält Sprechstunden und Raumangaben. Daneben bietet die Seite die Verwaltung eigener Dateien.', 'dispatch.php/profile', '3.1', 0, 0, 1, '', '', 1406641688),
('ebb5bc1d831d460c06e3c6662236c159', 'de', '', '', 'Hier kann ein Profilbild hochgeladen werden.', 'dispatch.php/settings/avatar', '3.1', 0, 0, 1, '', '', 1406641688),
('25255dc15fd0d6260bc1abd1f10aecc5', 'de', '', '', 'Individuelle persönliche Angaben, wie bspw. E-Mail-Adresse, können auf dieser Seite verändert und angepasst werden. ', 'dispatch.php/settings/account', '3.1', 0, 0, 1, '', '', 1406641688),
('d704267767d4c559aa9e552be60c49b5', 'de', '', '', 'Hier kann das Passwort für den Stud.IP-Account geändert werden.', 'dispatch.php/settings/password', '3.1', 0, 0, 1, '', '', 1406641688),
('cbd9b2b22fc00bc92df3589018644b70', 'de', '', '', 'Hier können vordefinierte Informationen über die eigene Person eingegeben werden, die auf der Profilseite erscheinen sollen. ', 'dispatch.php/settings/details', '3.1', 0, 0, 1, '', '', 1406641688),
('4e60dd9635f3d3fddecc78e0d1f646c7', 'de', '', '', 'Unter \"Studiendaten\" können manuell zusätzliche Studiengänge und Einrichtungen hinzugefügt werden, wenn sie nicht automatisch aus einem externen System (z.B. LSF/ UniVZ) übernommen wurden.', 'dispatch.php/settings/studies', '3.1', 0, 0, 1, '', '', 1406641688),
('462f1447b1a8a93ab7bdb2524f968b1a', 'de', '', '', 'Hier kann die Zugehörigkeit zu Nutzerdomänen eingesehen, aber nicht geändert werden.', 'dispatch.php/settings/userdomains', '3.1', 0, 0, 1, '', '', 1406641688),
('233564d01b8301ebec7ef2fe918d1290', 'de', '', '', 'Ansicht über die der/ dem Stud.IP-NutzerIn zugeordneten Einrichtungen.', 'dispatch.php/settings/statusgruppen', '3.1', 0, 0, 1, '', '', 1406641688),
('e315a4c547be7f17d427b227f0f9d982', 'de', '', '', 'Auf dieser Seite können selbstdefinierte Informationen über die eigene Person eingegeben werden, die auf der Profilseite erscheinen sollen. ', 'dispatch.php/settings/categories', '3.1', 0, 0, 1, '', '', 1406641688),
('ac5df1de9c75fc92af7718b2103d3037', 'de', '', '', 'Blubbern ist eine Mischform aus Forum und Chat. Nachrichten werden im öffentlichen Stream dargestellt. Andere Nutzer können über einen Beitrag informiert werden, indem sie per @benutzername oder @\"Vorname Nachname\" im Beitrag erwähnt werden.', 'plugins.php/blubber/streams/profile', '3.1', 0, 0, 1, '', '', 1406641688),
('4151003175042b71bea3529e5adc5a9e', 'de', '', '', 'Mit der Terminvergabe können Termine für Sprechstunden, Prüfungen usw. angelegt werden, in die sich Studierende selbst eintragen können.', 'plugins.php/homepageterminvergabeplugin/showadmin', '3.1', 0, 0, 1, '', '', 1406641688),
('63c2ecb12f30816aef0fb203eab4f40a', 'de', '', '', 'Hier können Termine angelegt und bearbeitet werden.', 'plugins.php/homepageterminvergabeplugin/show_category', '3.1', 0, 0, 1, '', '', 1406641688),
('164f77ab2cb7d38fd1ea20ed725834fd', 'de', '', '', 'Hier findet sich eine Übersicht über die Termine, die von Studierenden gebucht wurden.', 'plugins.php/homepageterminvergabeplugin/show_bookings', '3.1', 0, 0, 1, '', '', 1406641688),
('1289e991a93dce5a0b4edd678514325e', 'de', '', '', 'Hier können einzelne Inhaltselemente nachträglich aktiviert oder deaktiviert werden. Aktivierte Inhaltselemente fügen neue Funktionen zu Ihrem Profil oder Ihren Einstellungen hinzu. Diese werden meist als neuer Reiter im Menü erscheinen. Wenn Funktionalitäten nicht benötigt werden, können diese hier deaktiviert werden. Die entsprechenden Menüpunkte werden dann ausgeblendet.', 'dispatch.php/profilemodules', '3.1', 0, 0, 1, '', '', 1406641688),
('b677e8b5f1bd7e8acbe474177449c4e1', 'de', '', '', 'Die Dateiverwaltung bietet die Möglichkeit zum Hochladen, Verwalten und Herunterladen persönlicher Dateien, die nicht für andere einsehbar sind. ', 'dispatch.php/document/files', '3.1', 0, 0, 1, '', '', 1406641688),
('35b1860b95854a2533b6ecfbbf04ab71', 'de', '', '', 'Der Stundenplan besteht aus belegten Veranstaltungen, die ein- und ausgeblendet sowie in Darstellungsgröße und -form angepasst werden können.', 'dispatch.php/calendar/schedule', '3.1', 0, 0, 1, '', '', 1406641688),
('db5a995bd12ba8e2ae96adcabeb8c8f7', 'de', '', '', 'Der Terminkalender besteht aus belegten Veranstaltungen und eigenen Terminen. Er kann bearbeitet, in der Anzeige verändert und mit externen Programmen (z.B. Outlook) abgeglichen werden. ', 'calendar.php', '3.1', 0, 0, 1, '', '', 1406641688),
('87489a40097e5c26f1d1349c072610de', 'de', '', '', 'Mit der Veranstaltungssuche können Veranstaltungen, Studiengruppen usw. in verschiedenen Semestern und nach verschiedenen Suchkriterien (siehe \"Erweiterte Suche anzeigen\"in der Sidebar) gefunden werden. Das aktuelle Semester ist vorgewählt.', 'dispatch.php/search/courses', '3.1', 0, 0, 1, '', '', 1406641688),
('74863847eec53a3d4c8264d8de526be8', 'de', '', '', 'Mit der Archivsuche können Veranstaltungen gefunden werden, die bereits archiviert wurden.', 'archiv.php', '3.1', 0, 0, 1, '', '', 1406641688),
('14b77e9e0b7773c92db9e7344a23fcfc', 'de', '', '', 'Mit der Personensuche können NutzerInnen gefunden werden, solange deren Privatsphäre-Einstellung dies nicht verhindert. Die Suche kann auf bestimmte Veranstaltungen oder Einrichtungen begrenzt werden.', 'browse.php', '3.1', 0, 0, 1, '', '', 1406641688),
('4f9d79fe88e81486b8c1f192d70232d5', 'de', '', '', 'Mit der Einrichtungssuche können Einrichtungen über ein freies Suchfeld oder den Einrichtungsbaum gefunden werden.', 'institut_browse.php', '3.1', 0, 0, 1, '', '', 1406641688),
('014a2106d384c0ca55d9311597029ca0', 'de', '', '', 'Mit der Ressourcensuche können universitäre Ressourcen wie Räume, Gebäude etc. gefunden werden.', 'resources.php', '3.1', 0, 0, 1, '', '', 1406641688),
('60b6caf75d0004dfdb0a1adfd66027ed', 'de', '', '', 'Hier können Lehrende Ankündigungen für ihre Veranstaltungen, Einrichtungen und ihre Profilseite erstellen und anzeigen, wobei die Anzeige gefiltert werden kann.', 'dispatch.php/news/admin_news', '3.1', 0, 0, 1, '', '', 1406641688),
('f3deb7a01205637d71a66e2b90b24cba', 'de', '', '', 'Hier können RSS-Feeds, d.h. Nachrichtenströme von externen Internetseiten, auf der Startseite eingebunden werden. Je mehr Feeds eingebunden werden, desto länger dauert das Laden der Startseite.', 'dispatch.php/admin/rss_feeds', '3.1', 0, 0, 1, '', '', 1406641688),
('bc1d6ecab9364cfe2c549d262bfda437', 'de', '', '', 'Die Lernmodulschnittstelle ermöglicht es, Selbstlerneinheiten aus externen Programmen wie ILIAS und LON-CAPA in Stud.IP zur Verfügung zu stellen. Für jedes externe System wird ein eigener Benutzer-Account erstellt oder zugeordnet. Mit den entsprechenden Rechten können eigene Lernmodule erstellt werden.', 'dispatch.php/elearning/my_accounts', '3.1', 0, 0, 1, '', '', 1406641688),
('d1de152db139d8c12552610d2f7999c2', 'de', '', '', 'Mit dem Export können Daten über Veranstaltungen und MitarbeiterInnen in folgende Formate exportiert werden: RTF, TXT, CSV, PDF, HTML und XML.', 'export.php', '3.1', 0, 0, 1, '', '', 1406641688),
('2c55eab1f52d6f7d1021880836906f5b', 'de', '', '', 'Hier lassen sich Literaturlisten bearbeiten und in der Veranstaltung sichtbar schalten (mit Klick auf das \"Auge\").', 'dispatch.php/literature/edit_list.php', '3.1', 0, 0, 1, '', '', 1406641688);
";
        DBManager::get()->exec($query);
    }

    function addHelpContentEN() {
        $query = "
INSERT INTO `help_content` (`content_id`, `language`, `label`, `icon`, `content`, `route`, `studip_version`, `position`, `custom`, `visible`, `author_id`, `installation_id`, `mkdate`) VALUES
('c8e789a0efb73f00f00dacf565524c73', 'en', '', '', 'Various display options and notification features can be selected and changed in the general settings.', 'dispatch.php/settings/general', '3.1', 0, 0, 1, '', '', 1412942388),
('f5e59c4fc98e1df7fe29b8e9320853e7', 'en', '', '', 'The visibility and searchability for the own profile can be set in the privacy settings.', 'dispatch.php/settings/privacy', '3.1', 0, 0, 1, '', '', 1412942388),
('3b7a4c04017fef2984ee029610194f26', 'en', '', '', 'The settings of the message system offer the possibility e.g. to arrange for a forwarding of the messages received in Stud.IP to your e-mail address.', 'dispatch.php/settings/messaging', '3.1', 0, 0, 1, '', '', 1412942388),
('260ee12fdc7dccb30eca2cc075ef0096', 'en', '', '', 'The settings of the diary offer the possibility to adjust these to own needs .', 'dispatch.php/settings/calendar', '3.1', 0, 0, 1, '', '', 1412942388),
('43df8e33145c25eb6d941e4e845ada24', 'en', '', '', 'In the notification settings it is possible to select with which changes within a course notification is to be given.', 'dispatch.php/settings/notification', '3.1', 0, 0, 1, '', '', 1412942388),
('85c000e33732c5596d198776cb884860', 'en', '', '', 'In the standard substitution settings lecturers can stipulate a standard substitution, which can manage and change all courses of the lecturer.', 'dispatch.php/settings/deputies', '3.1', 0, 0, 1, '', '', 1412942388),
('b05b27450e363c38c6b4620b902b3496', 'en', '', '', 'The start page will be displayed after the log-in and can be customised to personal needs by using widgets.', 'dispatch.php/start', '3.1', 0, 0, 1, '', '', 1412942388),
('91d6f451c3ef8d8352a076773b0a19ee', 'en', '', '', 'The course page shows all subscribed courses (as a standard only those of the last two semesters), all subscribed study groups as well as all institutions, to which one was allocated. You can customise the display through colour groupings, semester filters, etc. ', 'dispatch.php/my_courses', '3.1', 0, 0, 1, '', '', 1412942388),
('0237ea35a203be81e44c979d82ef5ee6', 'en', '', '', 'Archived courses to which the user is allocated appear here. Contents can no longer be changed, however deposited documents can be downloaded as a zip file.', 'dispatch.php/my_courses/archive', '3.1', 0, 0, 1, '', '', 1412942388),
('d97eff1196f6aed8e94f7c5096ebd2a9', 'en', '', '', 'Course-related brief and detailed information, announcements, dates and surveys can be found in the overview.', 'dispatch.php/course/overview', '3.1', 0, 0, 1, '', '', 1412942388),
('357bbf06015b2738aae15837f581a07d', 'en', '', '', 'More detailed information about the course is displayed, such as e.g. the course number, allocations, lecturers, tutors, etc. In the detailed information it is possible to register for a course under actions.', 'dispatch.php/course/details', '3.1', 0, 0, 1, '', '', 1412942388),
('0c055cc6ae418a96ff3afa9db13098df', 'en', '', '', 'The properties of the course can be subsequently changed with the management functions. The simulation of the students view is possible under actions.', 'dispatch.php/course/management', '3.1', 0, 0, 1, '', '', 1412942388),
('615c1887f0ee080043f133681ebf0def', 'en', '', '', 'Title, description, lecturer, etc. can be changed in the basic data. The processing can partly be blocked if data are taken over from other systems (e.g. LSF/ UniVZ).', 'dispatch.php/course/basicdata/view', '3.1', 0, 0, 1, '', '', 1412942388),
('abfb5d03de288d02df436f9a8bb96d9d', 'en', '', '', 'The photo of the course, which can help students to distinguish between courses on the \"my courses\" page, can be changed with the photo-upload-function.', 'dispatch.php/course/avatar/update', '3.1', 0, 0, 1, '', '', 1412942388),
('eec46c5d8ea5523d959a8c334455c2ef', 'en', '', '', 'The course can be allocated to a field of study by using the field of study function. The processing can be blocked if data are taken over from other systems (e.g. LSF/ UniVZ).', 'dispatch.php/course/study_areas/show', '3.1', 0, 0, 1, '', '', 1412942388),
('85c709de75085bd56a739e4e8ac6fcad', 'en', '', '', 'The semester, date and room details of the course can be changed by using the time/room function. The processing can be blocked if data are taken over from other systems (e.g. LSF/ UniVZ).', 'raumzeit.php', '3.1', 0, 0, 1, '', '', 1412942388),
('4e14c94cda99e2ef6462f7fef06d9c91', 'en', '', '', 'The access to a course can be regulated with access authorisations (enrolment procedure) e.g. by passwords, time control and restriction to participants.', 'dispatch.php/course/admission', '3.1', 0, 0, 1, '', '', 1412942388),
('42060187921376807f90e52fad5f9822', 'en', '', '', '(Time-controlled) surveys or individual Multiple-/Single-Choice questions can be set up for courses, study groups or the profile by using the survey and test function.', 'admin_vote.php', '3.1', 0, 0, 1, '', '', 1412942388),
('5475d65b07fdaf5f234bf6eed3d5e4a9', 'en', '', '', 'With the evaluation function surveys can be set up with Multiple-Choice, Likert and free text questions for courses, study groups, the own profile or institutions. Public templates of other persons can be used hereby. All future, ongoing and ended evaluations are displayed.', 'admin_evaluation.php', '3.1', 0, 0, 1, '', '', 1412942388),
('80286432bf17df20e5f11f86b421b0a7', 'en', '', '', 'The forum is a text-based possibility, which is irrespective of time and place, to exchange questions, opinions and experience. Contributions can be subscribed to, exported, marked as favourites and edited. Various views (e.g. new contributions since the last login) can be chosen via the navigation links.', 'plugins.php/coreforum', '3.1', 0, 0, 1, '', '', 1412942388),
('3607d6daea679dcd7003e076fdd1660a', 'en', '', '', 'The list of participants shows a list of the participants of this course. Further participants can be added,  removed, downgraded, upgraded or allocated to self-defined groups by lecturers.', 'dispatch.php/course/members', '3.1', 0, 0, 1, '', '', 1412942388),
('f529bca4d1626b43cbb8149feea41a84', 'en', '', '', 'The self-defined groups are displayed here. Messages can be sent to these. A click on the orange arrows before the group name will allocate you to the group.', 'statusgruppen.php', '3.1', 0, 0, 1, '', '', 1412942388),
('bd5df4fb7b84da79149c96c5f43de46c', 'en', '', '', 'Groups can be set up and managed here. If the self-entry is activated participants can enter and remove themselves.', 'admin_statusgruppe.php', '3.1', 0, 0, 1, '', '', 1412942388),
('8c2fc90bd8175e6d598f895944a8ddc2', 'en', '', '', 'The attendance list shows all meetings (meeting, lecture, exercise, internship) of the schedule and enables the entry of students in Stud.IP by the lecturers as well as an export of the list for the overview or as a basis for handwritten entries.', 'participantsattendanceplugin/show', '3.1', 0, 0, 1, '', '', 1412942388),
('ee91ec0f9085221ada06d171a27d2405', 'en', '', '', 'The document administration offers the possibility to upload, link, administer and download documents. ', 'folder.php', '3.1', 0, 0, 1, '', '', 1412942388),
('8c3067596811d3c6857d253299e01f6f', 'en', '', '', 'The schedule displays dates, topics and rooms of the course. Individual dates can be edited, e.g. topics can be added to dates.', 'dispatch.php/course/dates', '3.1', 0, 0, 1, '', '', 1412942388),
('1f216fe42d879c3fcbb582d67e9ad5a2', 'en', '', '', 'Dates can be allocated topics here or already entered topics can be taken over and edited.', 'dispatch.php/course/topics', '3.1', 0, 0, 1, '', '', 1412942388),
('abaa7b076e6923ac43120f3326322af0', 'en', '', '', 'This page enables the deposit of free information, links, etc.', 'dispatch.php/course/scm', '3.1', 0, 0, 1, '', '', 1412942388),
('7edc08f2f7b0786ca036f8c448441e07', 'en', '', '', 'The Wiki enables a joint, asynchronous creation and editing of texts. Texts can be formatted and linked with each other so that a branched reference work is produced. ', 'wiki.php', '3.1', 0, 0, 1, '', '', 1412942388),
('44edb997707d1458cbf8a3f8f316b908', 'en', '', '', 'The bibliography page offers lecturers the possibility to create bibliographies or to import these from bibliography management programmes. These lists can be copied and placed visibly in courses. Research can be conducted in the actual book stocks of the university depending on the connection. ', 'dispatch.php/course/literature', '3.1', 0, 0, 1, '', '', 1412942388),
('1cb8fd77427ebc092d751eea95454b0a', 'en', '', '', 'Bibliographies can be edited here and placed visibly in the course (with a click on the \"eye\").', 'dispatch.php/literature/edit_list', '3.1', 0, 0, 1, '', '', 1412942388),
('b283b58820db358284f4451dfb691678', 'en', '', '', 'A search can be conducted for literature in catalogues here and these added to the clipboard.', 'dispatch.php/literature/search', '3.1', 0, 0, 1, '', '', 1412942388),
('0d83ce036f2870f873446230c0118bb7', 'en', '', '', 'The learning module interface makes it possible for self-learning units or tests to be made available from external programmes such as ILIAS and LON-CAPA in Stud.IP.', 'dispatch.php/course/elearning/show', '3.1', 0, 0, 1, '', '', 1412942388),
('8b690f942bf0cc0322e5bea0f1b9abed', 'en', '', '', 'Select the requested system and subsequently the learning module/ the test. Writing rights determine who may edit the learning module in future. The option \"update allocations\" is located in the sidebar in order to transfer changed contents e.g. in the ILIAS course to Stud.IP.', 'dispatch.php/course/elearning/edit', '3.1', 0, 0, 1, '', '', 1412942388),
('0838a96b5678e2fc26be0ee38ae67619', 'en', '', '', 'In DoIT! lecturers have the possibility to set various types of tasks, including the uploading of files, Multiple-Choice questions and Peer Reviewing. The processing of tasks can be time limited and alternatively carried out in groups.', 'plugins.php/reloadedplugin/show', '3.1', 0, 0, 1, '', '', 1412942388),
('1804e526c2f6794b877a4b2096eaa67a', 'en', '', '', 'Blubbering is a mixed form of forum and chat, with which contributions of the participants are displayed in real time. Others can be informed about a contribution by the fact that they are mentioned in the contribution by @user name or @''first name''.', 'plugins.php/blubber/streams/forum', '3.1', 0, 0, 1, '', '', 1412942388),
('38d1a86517eb6cc195b2e921270c3035', 'en', '', '', 'The group calendar offers an overview of course dates and personalised additional dates for this course. ', 'plugins.php/gruppenkalenderplugin/show', '3.1', 0, 0, 1, '', '', 1412942388),
('852991dc733639dd2df05fb627abf3db', 'en', '', '', 'Further features can be added to the course here.', 'dispatch.php/course/plus', '3.1', 0, 0, 1, '', '', 1412942388),
('1ea099717ceb1b401aedcedc89814d9c', 'en', '', '', 'The learning diary supports the self-controlled learning process of the students and is kept independently by them. Enquiries for work steps to the lecturers are possible, certain data can be released individualised.', 'plugins.php/lerntagebuchplugin/overview', '3.1', 0, 0, 1, '', '', 1412942388),
('2075fe42f56207fbd153a810188f1beb', 'en', '', '', 'Configuration of the learning diary for students and creation of a learning diary for the lecturers.', 'plugins.php/lerntagebuchplugin/admin_settings', '3.1', 0, 0, 1, '', '', 1412942388),
('7465a4aeedb6a320d3455cf9ad0bebd0', 'en', '', '', 'Possibility for providing lecture recordings and pod casts for students of the course (by linking to the documents on the media server). ', 'plugins.php/mediacastsplugin/show', '3.1', 0, 0, 1, '', '', 1412942388),
('02b4e3ce7b8fe6b3e6a3586d410a51a1', 'en', '', '', 'This page displays the study groups to which the user is allocated. Study groups are a simple possibility to cooperate with fellow students, colleagues and others. Each user can create study groups or search for them. The colour grouping can be adjusted individually.', 'dispatch.php/my_studygroups', '3.1', 0, 0, 1, '', '', 1412942388),
('af7573cce1e898054db89a96284866f9', 'en', '', '', 'A new study group can be created here. Each Stud.IP user can create study groups and configure these according to own needs.', 'dispatch.php/course/studygroup/new', '3.1', 0, 0, 1, '', '', 1412942388),
('960d7bafb618853eced1b1b42a7dd412', 'en', '', '', 'This page displays all study groups, which exist in Stud.IP. Study groups are a simple possibility to cooperate with fellow students, colleagues and others. Each user can create study groups or search for them.', 'dispatch.php/studygroup/browse', '3.1', 0, 0, 1, '', '', 1412942388),
('3d040e95a8c29e733a8d5439ee9f5b59', 'en', '', '', 'The name, functions and access restriction of the study group can be edited here.', 'dispatch.php/course/studygroup/edit', '3.1', 0, 0, 1, '', '', 1412942388),
('b3bd33cb0babbb0cc51a4f429d15d438', 'en', '', '', 'Here you can add new memebers to the study group und send them messages.', 'dispatch.php/course/studygroup/members', '3.1', 0, 0, 1, '', '', 1412942388),
('438c4456f85afec29fd9f47c111136c1', 'en', '', '', 'This page displays the institutions to which the user is allocated.', 'dispatch.php/my_institutes', '3.1', 0, 0, 1, '', '', 1412942388),
('f966e348174927565b94e606bbcf064f', 'en', '', '', 'The message page offers an overview on received, system-internal messages, which can be issued with self-chosen key words (so-called tags) in order to subsequently be able to find them easier.', 'dispatch.php/messages/overview', '3.1', 0, 0, 1, '', '', 1412942388),
('ceb21257092b11dcf6897d5bb3085642', 'en', '', '', 'Overview on sent, system-internal messages, which can be issued with self-chosen key words (so-called \"tags\") in order to subsequently be able to find them easier. ', 'dispatch.php/messages/sent', '3.1', 0, 0, 1, '', '', 1412942388),
('b9586c280a0092f86f9392fe5b5ff2a0', 'en', '', '', 'Blubbering is the Stud.IP real time forum, a mixed form of forum and chat. Others can be informed about a contribution by the fact that they are mentioned in the contribution by @user name or @''first name''. Texts can be formatted and supplemented by Smileys.', 'plugins.php/blubber/streams/global', '3.1', 0, 0, 1, '', '', 1412942388),
('7cb7026818c4b90935009d0548300674', 'en', '', '', 'A user-defined blubber stream can be created here. It always consists of a collection of contributions from selected courses, contact groups and key words, which can be restricted even further based on a filtering. The new user-defined stream can be found after clicking on the save button in the navigation under global stream.', 'plugins.php/blubber/streams/edit', '3.1', 0, 0, 1, '', '', 1412942388),
('2f1602394a4e31c2e30706f0a0b3112f', 'en', '', '', 'On this page it can be viewed which contacts are online at the moment. A message can be sent to these persons. The clicking on the name of one person forwards to their profile.', 'dispatch.php/online', '3.1', 0, 0, 1, '', '', 1412942388),
('27c4d9837cfb1a9a40c079e16daac902', 'en', '', '', 'This page offers the possibility to enter Stud.IP users in the address book and to list all contacts who can already be found in the address book.', 'contact.php', '3.1', 0, 0, 1, '', '', 1412942388),
('362a67fff2ef7af8cca9f8e20583c9f2', 'en', '', '', 'Contacts from the address book can be displayed sorted according to the groups here.', '???', '3.1', 0, 0, 1, '', '', 1412942388),
('6b331f5cc2176daba82a0cc71aaa576f', 'en', '', '', 'Contacts from the address book can be sorted in self-defined groups on this page.', 'contact_statusgruppen.php', '3.1', 0, 0, 1, '', '', 1412942388),
('57f1b29d3c1a558f5cc799c1aade7f14', 'en', '', '', 'Contact groups or the whole address book can be exported here in order to be able to import them in an external programme.', 'contact_export.php', '3.1', 0, 0, 1, '', '', 1412942388),
('90ffbd715843b02b3961907f81caf208', 'en', '', '', 'The ranking sorts the Stud.IP users in descending order based on their number of points. The number of points will grow with the activities in Stud.IP and thus represents the experience of the users with the system. By entering a check mark in the little box on the left the own value will be made visible in the ranking for other users. The own value is not visible to the public in the basic settings.', 'dispatch.php/score', '3.1', 0, 0, 1, '', '', 1412942388),
('e5bff29f7adee43202a2aa8f3f0a6ec7', 'en', '', '', 'You can change your own user data incl. profile photo and categories here. Comments can be left similar to Facebook. The profile of lecturers includes consulting hours and room details. In addition the page offers the administration of own documents.', 'dispatch.php/profile', '3.1', 0, 0, 1, '', '', 1412942388),
('2a389c2472656121a76ca4f3b0e137d4', 'en', '', '', 'A profile photo can be uploaded here.', 'dispatch.php/settings/avatar', '3.1', 0, 0, 1, '', '', 1412942388),
('fe23b56f4d691c0f5e2f872e37ce38b5', 'en', '', '', 'You can change and customise your individual user data, such as for example mail address, on this page. ', 'dispatch.php/settings/account', '3.1', 0, 0, 1, '', '', 1412942388),
('b32cb2c4ec56e925b07a5cb0105a6888', 'en', '', '', 'The password for the Stud.IP-Account can be changed here.', 'dispatch.php/settings/password', '3.1', 0, 0, 1, '', '', 1412942388),
('83fd70727605c485a0d8f2c5ef94289b', 'en', '', '', 'Pre-defined information about the own person can be entered here, which is to appear on the profile page. ', 'dispatch.php/settings/details', '3.1', 0, 0, 1, '', '', 1412942388),
('970ebdf39ad5ca89083a52723c5c35f5', 'en', '', '', 'Additional courses of study and institutions can be added manually under \"study details\", if they are not automatically taken over from an external system (e.g. LSF/UniVZ).', 'dispatch.php/settings/studies', '3.1', 0, 0, 1, '', '', 1412942388),
('0e816d9428a3bc8a73fb0042fb2da540', 'en', '', '', 'The affiliation to user domains can be viewed, however not changed, here.', 'dispatch.php/settings/userdomains', '3.1', 0, 0, 1, '', '', 1412942388),
('d04ca1f9e867ee295a3025dac7ce9c7b', 'en', '', '', 'View of the institutions allocated to the Stud.IP user.', 'dispatch.php/settings/statusgruppen', '3.1', 0, 0, 1, '', '', 1412942388),
('8ad364363acd415631226d5574d5592a', 'en', '', '', 'Self-defined information about the own person can be entered on this page, which is to appear on the profile page. ', 'dispatch.php/settings/categories', '3.1', 0, 0, 1, '', '', 1412942388),
('51a0399250de6365619c961ec3669ad3', 'en', '', '', 'Blubbering is a mixed form of forum and chat. Messages are presented in the public stream. Other users can be informed about a contribution by the fact that they are mentioned in the contribution by @user name or @''first name last name''.', 'plugins.php/blubber/streams/profile', '3.1', 0, 0, 1, '', '', 1412942388),
('5ae72abc0822570bfe839e3ee24f0c81', 'en', '', '', 'With the allocation of dates, dates can be created for consulting hours, examinations, etc., in which students can enter themselves.', 'plugins.php/homepageterminvergabeplugin/showadmin', '3.1', 0, 0, 1, '', '', 1412942388),
('76195b21d485823fd7ca2fd499131c12', 'en', '', '', 'Dates can be created and edited here.', 'plugins.php/homepageterminvergabeplugin/show_category', '3.1', 0, 0, 1, '', '', 1412942388),
('0ad754cc62d1e86e97c1a28dd68ac40c', 'en', '', '', 'An overview on the dates, which were booked by students can be found here.', 'plugins.php/homepageterminvergabeplugin/show_bookings', '3.1', 0, 0, 1, '', '', 1412942388),
('b5fabb1e5aed7ff8520314e9a86c5c87', 'en', '', '', 'Individual content elements can be subsequently activated or deactivated here. Activated content elements add new functions to your profile or your settings. These will mostly appear as a new tab in the menu. If functionalities are not required these can be deactivated here. The corresponding menu tabs are then faded out.', 'dispatch.php/profilemodules/index', '3.1', 0, 0, 1, '', '', 1412942388),
('51b98d659590e1e37dae5e5e5cc028bb', 'en', '', '', 'The document administration offers the possibility to upload, manage and download personal documents,which cannot be viewed by others. ', 'dispatch.php/document/files', '3.1', 0, 0, 1, '', '', 1412942388),
('440e50f7fcc825368aa9026273d2cd0d', 'en', '', '', 'The schedule of studies consists of subscribed courses, which can be faded in and out as well as customised in the size and form of the presentation.', 'dispatch.php/calendar/schedule', '3.1', 0, 0, 1, '', '', 1412942388),
('dddf5fd4406da0d91c9f121fcae607ad', 'en', '', '', 'The diary consists of subscribed courses and own dates. It can be edited, change in the display and compared with external programmes (e.g. Outlook). ', 'calendar.php', '3.1', 0, 0, 1, '', '', 1412942388),
('a1e3da35edc9b605f670e9c7f5019888', 'en', '', '', 'With the course search courses, study groups, etc. can be found in various semesters and according to various search criteria (see \"display extended search\" in the sidebar). The current semester is pre-selected.', 'dispatch.php/search/courses', '3.1', 0, 0, 1, '', '', 1412942388),
('7d40379f54250b550065e062d71e8fd8', 'en', '', '', 'Various courses can be found with the archive search, which have already been archived.', 'archiv.php', '3.1', 0, 0, 1, '', '', 1412942388),
('ebcc460880b8a63af3f6e7eade97db78', 'en', '', '', 'Users can be found with the search for persons as long as their privacy setting does not prevent this. The search can be limited to certain courses or institutions.', 'browse.php', '3.1', 0, 0, 1, '', '', 1412942388),
('8a32ca4e602a68307d4ae6ae51fa667e', 'en', '', '', 'With the institution search institutions can be found via a free search field or the institution tree', 'institut_browse.php', '3.1', 0, 0, 1, '', '', 1412942388),
('e206a4257e31a0f32ac516cefb8e8331', 'en', '', '', 'University resources such as rooms, buildings, etc. can be found using the resource search.', 'resources.php', '3.1', 0, 0, 1, '', '', 1412942388),
('3318ee99a062079b463e902348ad520e', 'en', '', '', 'Lecturers can create and display announcements for their courses, institutions and their profile page here, whereby the display can be filtered.', 'dispatch.php/news/admin_news', '3.1', 0, 0, 1, '', '', 1412942388),
('bcdedaf1b4bd3b96ef574e8230095b28', 'en', '', '', 'RSS-Feeds, i.e. message streams of external websites, can be integrated onto the start page here. The more feeds are integrated, the longer the loading of the start page will take.', 'dispatch.php/admin/rss_feeds', '3.1', 0, 0, 1, '', '', 1412942388),
('bfb70d5f036769d740fb2342b0b58183', 'en', '', '', 'The learning module interface makes it possible for self-learning units to be made available from external programmes such as ILIAS and LON-CAPA in Stud.IP. An own user account will be created or allocated for each external system. Own learning modules can be created with the corresponding rights.', 'dispatch.php/elearning/my_accounts', '3.1', 0, 0, 1, '', '', 1412942388),
('7bf322a6c5f13db67e047b7afae83e58', 'en', '', '', 'With the export data about courses and employees can be exported in the following formats: RTF, TXT, CSV, PDF, HTML and XML.', 'export.php', '3.1', 0, 0, 1, '', '', 1412942388),
('fa4bf491690645a5f12556f77e51233c', 'en', '', '', 'Bibliographies can be edited here and placed visibly in the course (with a click on the \"eye\").', 'dispatch.php/literature/edit_list.php', '3.1', 0, 0, 1, '', '', 1412942388);

        ";
        DBManager::get()->exec($query);
    }
}
